;;; The following are bug templates (scions) utilized in the experimental
;;; evaluation of Bug-Injector.
;;; Templates derived from Clang Static Analyzer (CSA) are prefixed with
;;; "clang-", while templates derived from Facebook Infer are prefixed with
;;; "infer-".  Similarly, Juliet bug templates are prefixed with "CWE".  To
;;; differentiate between templates derived from the CSA and Facebook Infer
;;; documentation and those derived from regression tests, the tag
;;; "regression-test" is included in the template name.
;;;
;;; As described in Section III of the paper, the bug templates contain free
;;; variable, precondition, and code fields.  Here these fields are presented
;;; in their concrete form; for instance, preconditions are expressed as
;;; Common Lisp lambda expressions.  Additionally, for efficiency, the Juliet
;;; scions use a serialized format for several fields.  For simplicity,
;;; some fields were elided from consideration in the paper, but are present
;;; here, including options for macros, types, and other constructs required
;;; for successful scion injection.


;; Clang documentation example - null pointer dereference
;;void test(int *p) {
;;  if (p)
;;    return;
;;
;;  int x = p[0]; // warn
;;}
(defparameter clang-pointer-dereference1-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (let ((ast (ast-at-index obj location)))
                      (and (= (v/value p) 0)
                           (ast-void-ret (function-containing-ast obj ast))
                           (var-declarable-p obj ast "x"))))
    :free-variables '(("p" "*int"))
    :code "if (p) {
    return;
}
/* POTENTIAL FLAW */
int x = p[0];"))
(define-scion clang-pointer-dereference1
    (make-instance 'clang-scion
                   :name 'clang-pointer-dereference1
                   :patches (list clang-pointer-dereference1-patch)))

;; Clang documentation example - null pointer dereference
;; void test(int *p) {
;;  if (!p)
;;    *p = 0; // warn
;;}
(defparameter clang-pointer-dereference2-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (declare (ignorable obj location))
                    (= (v/value p) 0))
    :free-variables '(("p" "*int" :-const))
    :code "if (!p) {
    /* POTENTIAL FLAW */
    *p = 0;
}"))
(define-scion clang-pointer-dereference2
    (make-instance 'clang-scion
                   :name 'clang-pointer-dereference2
                   :patches (list clang-pointer-dereference2-patch)))

;; Clang documentation example - null pointer dereference
;;int test() {
;;  return strlen(0); // warn
;;}
(defparameter clang-pointer-dereference3-trivial-patch
  (make-instance 'clang-dynamic-patch
    :precondition  nil
    :free-variables '()
    :includes '("<string.h>")
    :code "/* POTENTIAL FLAW */
strlen(0);"))
(define-scion clang-pointer-dereference3-trivial
    (make-instance 'clang-scion
                   :name 'clang-pointer-dereference3-trivial
                   :patches (list clang-pointer-dereference3-trivial-patch)))

;; Clang documentation example - null pointer dereference
;;int test() {
;;  return strlen(0); // warn
;;}
(defparameter clang-pointer-dereference3-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location x)
                    (declare (ignorable obj location))
                    (= (v/value x) 0))
    :free-variables '(("x" "*char"))
    :includes '("<string.h>")
    :code "/* POTENTIAL FLAW */
strlen(x);"))
(define-scion clang-pointer-dereference3
    (make-instance 'clang-scion
                   :name 'clang-pointer-dereference3
                   :patches (list clang-pointer-dereference3-patch)))

;; Clang documentation example - buffer overflow
;; void test() {
;;  char *s = "";
;;  char c = s[1]; // warn
;;}
(defparameter clang-buffer1-trivial-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (vars-declarable-p obj
                                       (ast-at-index obj location)
                                       (list "s" "c")))
    :free-variables '()
    :code "char *s = \"\";
/* POTENTIAL FLAW */
char c = s[1];"))
(define-scion clang-buffer1-trivial
    (make-instance 'clang-scion
                   :name 'clang-buffer1-trivial
                   :patches (list clang-buffer1-trivial-patch)))

;; Clang documentation example - buffer overflow
;; void test() {
;;  char *s = "";
;;  char c = s[1]; // warn
;;}
(defparameter clang-buffer1-patch
  (make-instance 'clang-dynamic-patch
    :precondition nil
    :free-variables '(("s" "*char" :-const) ("c" "char" :-const))
    :code "s = \"\";
/* POTENTIAL FLAW */
c = s[1];
c++;"))
(define-scion clang-buffer1
    (make-instance 'clang-scion
                   :name 'clang-buffer1
                   :patches (list clang-buffer1-patch)))

;; Clang documentation example - buffer overflow
;;void test() {
;;  int buf[100];
;;  int *p = buf;
;;  p = p + 99;
;;  p[1] = 1; // warn
;;}
(defparameter clang-buffer2-trivial-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (vars-declarable-p obj
                                       (ast-at-index obj location)
                                       (list "buf" "p")))
    :free-variables '()
    :code "int buf[100];
int *p = buf;
p = p + 99;
/* POTENTIAL FLAW */
p[1] = 1;"))
(define-scion clang-buffer2-trivial
    (make-instance 'clang-scion
                   :name 'clang-buffer2-trivial
                   :patches (list clang-buffer2-trivial-patch)))

;; Clang documentation example - buffer overflow
;;void test() {
;;  int buf[100];
;;  int *p = buf;
;;  p = p + 99;
;;  p[1] = 1; // warn
;;}
(defparameter clang-buffer2-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (declare (ignorable p))
                    (var-declarable-p obj (ast-at-index obj location) "buf"))
    :free-variables '(("p" "*int" :-const))
    :code "int buf[100];
p = buf;
p = p + 99;
/* POTENTIAL FLAW */
p[1] = 1;"))
(define-scion clang-buffer2
    (make-instance 'clang-scion
                   :name 'clang-buffer2
                   :patches (list clang-buffer2-patch)))

;; Clang documentation example - buffer overflow
;;void test() {
;;  int buf[100][100];
;;  buf[0][-1] = 1; // warn
;;}
(defparameter clang-buffer3-trivial-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (var-declarable-p obj
                                      (ast-at-index obj location)
                                      "buf"))
    :free-variables '()
    :code "int buf[100][100];
/* POTENTIAL FLAW */
buf[0][-1] = 1;"))
(define-scion clang-buffer3-trivial
    (make-instance 'clang-scion
                   :name 'clang-buffer3-trivial
                   :patches (list clang-buffer3-trivial-patch)))

;; Clang documentation example - buffer overflow
;;void test() {
;;  int buf[100][100];
;;  buf[0][-1] = 1; // warn
;;}
(defparameter clang-buffer3-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (declare (ignorable p))
                    (var-declarable-p obj (ast-at-index obj location) "buf"))
    :free-variables '(("p" "*int" :-const))
    :code "int buf[100][100];
p = &buf[0][-1];
/* POTENTIAL FLAW */
p[0] = 1;"))
(define-scion clang-buffer3
    (make-instance 'clang-scion
                   :name 'clang-buffer3
                   :patches (list clang-buffer3-patch)))

;; Clang documentation example - buffer overflow
;;void test(int n) {
;;  void *p = malloc(n * sizeof(int)); // warn
;;}
(defparameter clang-buffer4-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location n p)
                    (declare (ignorable obj location p))
                    (> (* (v/value n) 4) +max-int-32+))
    :free-variables '(("n" "int") ("p" "*void" :-const))
    :code "/* POTENTIAL FLAW */
p = malloc(n * sizeof(int));"))
(define-scion clang-buffer4
    (make-instance 'clang-scion
                   :name 'clang-buffer4
                   :patches (list clang-buffer4-patch)))

;; Clang documentation example - buffer overflow
;;static int A[10];
;;
;;int *test() {
;;  int *p = A + 10;
;;  return p; // warn
;;}
(defparameter clang-buffer5-patch1
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
                    (declare (ignorable obj))
                    (= location 0))
    :free-variables nil
    :code "static int A[10];"
    :code-top-level-p t))
(defparameter clang-buffer5-trivial-patch2
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (when-let* ((ast (ast-at-index obj location))
                                (return-type (some->> (function-containing-ast
                                                        obj ast)
                                                      (ast-ret)
                                                      (find-type obj))))
                      (and (string= "int" (type-name return-type))
                           (type-pointer return-type)
                           (var-declarable-p obj ast "p"))))
    :free-variables '()
    :dependencies (list clang-buffer5-patch1)
    :code "int *p = A + 10;
/* POTENTIAL FLAW */
return p;"))
(define-scion clang-buffer5-trivial
    (make-instance 'clang-scion
                   :name 'clang-buffer5-trivial
                   :patches (list clang-buffer5-patch1
                                  clang-buffer5-trivial-patch2)))

(defparameter clang-buffer5-patch2
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (declare (ignorable p))
                    (when-let ((return-type
                                 (some->> (ast-at-index obj location)
                                          (function-containing-ast obj)
                                          (ast-ret)
                                          (find-type obj))))
                      (and (string= "int" (type-name return-type))
                           (type-pointer return-type))))
    :free-variables '(("p" "*int" :-const))
    :dependencies (list clang-buffer5-patch1)
    :code "p = A + 10;
/* POTENTIAL FLAW */
return p;"))
(define-scion clang-buffer5
    (make-instance 'clang-scion
                   :name 'clang-buffer5
                   :patches (list clang-buffer5-patch1
                                  clang-buffer5-patch2)))

;; Infer inferbo blog example - buffer overflow
(defparameter infer-buffer1-patch1
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
                    (declare (ignorable obj))
                    (= location 0))
    :free-variables nil
    :code-top-level-p t
    :code "void set_i(int *arr, int index) {
  arr[index] = 0;
}"))

(defparameter infer-buffer1-patch2
  (make-instance 'clang-dynamic-patch
    :precondition nil
    :free-variables '(("arr" "*int" :-const))
    :dependencies (list infer-buffer1-patch1)
    :includes (list "<stdlib.h>")
    :code "arr = (int *)malloc(9*sizeof(int));
if (arr != NULL) {
    int i;
    for (i = 0; i < 9; i+=1) {
        set_i(arr, i);
        /* POTENTIAL FLAW */
        set_i(arr, i + 1);
    }
}"))
(define-scion infer-buffer1
    (make-instance 'clang-scion
                   :name 'infer-buffer1
                   :patches (list infer-buffer1-patch1
                                  infer-buffer1-patch2)))


;; Infer inferbo blog example - buffer overflow
(defparameter infer-buffer2-patch
  (make-instance 'clang-dynamic-patch
    :precondition nil
    :free-variables '(("arr" "*int" :-const))
    :includes '("<stdlib.h>")
    :code "arr = (int *)malloc(9*sizeof(int));
if (arr != NULL) {
    int i;
    for (i = 0; i < 9; i++) {
        arr[i] = 0;
        /* POTENTIAL FLAW */
        arr[i+1] = 0;
    }
}"))
(define-scion infer-buffer2
    (make-instance 'clang-scion
                   :name 'infer-buffer2
                   :patches (list infer-buffer2-patch)))

;; Clang regression tests
;; tests from file clang/test/Analysis/null-deref-path-notes.c
(defparameter clang-regression-test-pointer-dereference1-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location a)
                    (declare (ignorable obj location))
                    (= (v/value a) 0))
    :free-variables '(("a" "*int"))
    :code "/* POTENTIAL FLAW */
(a + 0)[0];"))
(define-scion clang-regression-test-pointer-dereference1
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference1
                   :patches (list clang-regression-test-pointer-dereference1-patch)))

;; tests from file clang/test/Analysis/null-deref-path-notes.c
(defparameter clang-regression-test-pointer-dereference2-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location destination source)
                    (declare (ignorable obj location source))
                    (= (v/value destination) 0))
    :free-variables '(("destination" "*char" :-const) ("source" "*char"))
    :includes '("<string.h>")
    :code "/* POTENTIAL FLAW */
memcpy(destination + 0, source, 10);"))
(define-scion clang-regression-test-pointer-dereference2
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference2
                   :patches (list clang-regression-test-pointer-dereference2-patch)))

;; tests from file clang/test/Analysis/null-deref-path-notes.c
(defparameter clang-regression-test-pointer-dereference3-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location destination source)
                    (declare (ignorable obj location source))
                    (= (v/value destination) 0))
    :free-variables '(("destination" "*char" :-const) ("source" "*char"))
    :includes '("<string.h>")
    :code "/* POTENTIAL FLAW */
memcpy(destination - 0, source, 10);"))
(define-scion clang-regression-test-pointer-dereference3
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference3
                   :patches (list clang-regression-test-pointer-dereference3-patch)))

;; tests from file clang/test/Analysis/null-deref-path-notes.c
(defparameter clang-regression-test-pointer-dereference4-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location destination source)
                    (declare (ignorable obj location source))
                    (= (v/value destination) 0))
    :free-variables '(("destination" "*char" :-const) ("source" "*char"))
    :includes '("<string.h>")
    :code "destination = destination + 0;
/* POTENTIAL FLAW */
memcpy(destination, source, 10);"))
(define-scion clang-regression-test-pointer-dereference4
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference4
                   :patches (list clang-regression-test-pointer-dereference4-patch)))

;; tests from file clang/test/Analysis/null-deref-path-notes.c
(defparameter clang-regression-test-pointer-dereference5-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location dest1 dest2 src)
                    (declare (ignorable obj location dest2 src))
                    (= (v/value dest1) 0))
    :free-variables '(("dest1" "*char") ("dest2" "*char" :-const) ("src" "*char"))
    :includes '("<string.h>")
    :code "dest2 = dest1 - 0;
/* POTENTIAL FLAW */
memcpy(dest2, src, 10);"))
(define-scion clang-regression-test-pointer-dereference5
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference5
                   :patches (list clang-regression-test-pointer-dereference5-patch)))

;; tests from file clang/test/Analysis/diagnostics/text-diagnostics.c
(defparameter clang-regression-test-pointer-dereference6-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (declare (ignorable obj location))
                    (= (v/value p) 0))
    :free-variables '(("p" "*int" :-const))
    :code "/* POTENTIAL FLAW */
*p = 1;"))
(define-scion clang-regression-test-pointer-dereference6
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference6
                   :patches (list clang-regression-test-pointer-dereference6-patch)))

;; tests from file clang/test/Analysis/diagnostics/text-diagnostics.c
(defparameter clang-regression-test-pointer-dereference7-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location q)
                    (and (= (v/value q) 0)
                         (some->> (ast-at-index obj location)
                                  (function-containing-ast obj)
                                  (ast-void-ret))))
    :free-variables '(("q" "*int" :-const))
    :code "if (q) {
    return;
}
/* POTENTIAL FLAW */
*q = 1;"))
(define-scion clang-regression-test-pointer-dereference7
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference7
                   :patches (list clang-regression-test-pointer-dereference7-patch)))

;; tests from
;; file clang/test/Analysis/html_diagnostics/relevant_lines/macros_same_file.c
(defparameter clang-regression-test-pointer-dereference8-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location coin)
                    (and (not (= (v/value coin) 0))
                         (equal "int"
                                (some->> (ast-at-index obj location)
                                         (function-containing-ast obj)
                                         (ast-ret)
                                         (find-type obj)
                                         (type-trace-string)))))
    :free-variables '(("coin" "int"))
    :macros (list (make-clang-macro :name "deref"
                                    :body "deref(X) (*X)"
                                    :hash 0))
    :code "if (coin) {
    int *x = 0;
    /* POTENTIAL FLAW */
    return deref(x);
} else {
    return 0;
}"))
(define-scion clang-regression-test-pointer-dereference8
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference8
                   :patches (list clang-regression-test-pointer-dereference8-patch)))

;; tests from
;; file clang/test/Analysis/inlining/eager-reclamation-path-notes.c
(defparameter clang-regression-test-pointer-dereference9-patch1
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
                    (declare (ignorable obj))
                    (= location 0))
    :free-variables nil
    :code-top-level-p t
    :code "void use(int *ptr, int val) {
    *ptr = val;
}
int compute() {
    return 2 + 3 + 4 + 5 + 6;
}"))
(defparameter clang-regression-test-pointer-dereference9-patch2
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (declare (ignorable obj location))
                    (= (v/value p) 0))
    :free-variables '(("p" "*int" :-const))
    :dependencies (list clang-regression-test-pointer-dereference9-patch1)
    :code "/* POTENTIAL FLAW */
use(p, compute());"))
(define-scion clang-regression-test-pointer-dereference9
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference9
                   :patches (list clang-regression-test-pointer-dereference9-patch1
                                  clang-regression-test-pointer-dereference9-patch2)))

;; tests from
;; file clang/test/Analysis/inlining/eager-reclamation-path-notes.c
(defparameter clang-regression-test-pointer-dereference10-patch1
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
                    (declare (ignorable obj))
                    (= location 0))
    :free-variables nil
    :code-top-level-p t
    :code "void use2(int *ptr, int val) {
    *ptr = val;
}
int compute() {
    return 2 + 3 + 4 + 5 + 6;
}
void passThrough(int *p) {
  use2(p, compute());
}"))
(defparameter clang-regression-test-pointer-dereference10-patch2
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location ptr)
                    (declare (ignorable obj location))
                    (= (v/value ptr) 0))
    :free-variables '(("ptr" "*int" :-const))
    :dependencies (list clang-regression-test-pointer-dereference10-patch1)
    :code "/* POTENTIAL FLAW */
passThrough(ptr);"))
(define-scion clang-regression-test-pointer-dereference10
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference10
                   :patches (list clang-regression-test-pointer-dereference10-patch1
                                  clang-regression-test-pointer-dereference10-patch2)))

;; tests from file clang/test/Analysis/inline-unique-reports.c
(defparameter clang-regression-test-pointer-dereference11-patch1
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
                    (declare (ignorable obj))
                    (= location 0))
    :free-variables nil
    :code-top-level-p t
    :code "static void bug(int *p) {
    *p = 0xDEADBEEF;
}"))
(defparameter clang-regression-test-pointer-dereference11-patch2
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location ptr)
                    (declare (ignorable obj location))
                    (= (v/value ptr) 0))
    :free-variables '(("p" "*int" :-const))
    :dependencies (list clang-regression-test-pointer-dereference11-patch1)
    :code "/* POTENTIAL FLAW */
bug(p);"))
(define-scion clang-regression-test-pointer-dereference11
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference11
                   :patches (list clang-regression-test-pointer-dereference11-patch1
                                  clang-regression-test-pointer-dereference11-patch2)))

;; tests from file clang/test/Analysis/inline.c
(defparameter clang-regression-test-pointer-dereference12-patch1
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
                    (declare (ignorable obj))
                    (= location 0))
    :free-variables nil
    :code-top-level-p t
    :code "int test1_f1() {
    int y = 1;
    y++;
    return y;
}"))
(defparameter clang-regression-test-pointer-dereference12-patch2
  (make-instance 'clang-dynamic-patch
    :precondition nil
    :free-variables '(("x" "int" :-const))
    :dependencies (list clang-regression-test-pointer-dereference12-patch1)
    :code "x = 1;
x = test1_f1();
if (x == 1) {
    int *p = 0;
    *p = 3;
}
if (x == 2) {
    int *p = 0;
    /* POTENTIAL FLAW */
    *p = 3;
}"))
(define-scion clang-regression-test-pointer-dereference12
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference12
                   :patches (list clang-regression-test-pointer-dereference12-patch1
                                  clang-regression-test-pointer-dereference12-patch2)))

;; tests from file clang/test/Analysis/inline.c
(defparameter clang-regression-test-pointer-dereference13-patch1
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
                    (declare (ignorable obj))
                    (= location 0))
    :free-variables nil
    :code-top-level-p t
    :code "unsigned factorial(unsigned x) {
    if (x <= 1)
        return 1;
    return x * factorial(x - 1);
}"))
(defparameter clang-regression-test-pointer-dereference13-patch2
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (declare (ignorable obj location))
                    (= (v/value p) 0))
    :free-variables '(("p" "*int" :-const))
    :dependencies (list clang-regression-test-pointer-dereference13-patch1)
    :code "if (factorial(3) == 6) {
    /* POTENTIAL FLAW */
    *p = 0xDEADBEEF;
}"))
(define-scion clang-regression-test-pointer-dereference13
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference13
                   :patches (list clang-regression-test-pointer-dereference13-patch1
                                  clang-regression-test-pointer-dereference13-patch2)))

;; tests from file
;; clang/test/Analysis/html_diagnostics/relevant_lines/simple_conditional.c
(defparameter clang-regression-test-pointer-dereference14-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location coin)
                    (declare (ignorable obj location))
                    (and (= (v/value coin) 0)
                         (equal "int"
                                (some->> (ast-at-index obj location)
                                         (function-containing-ast obj)
                                         (ast-ret)
                                         (find-type obj)
                                         (type-trace-string)))))
    :free-variables '(("coin" "int"))
    :code "if (coin) {
    int *x = 0;
    /* POTENTIAL FLAW */
    return *x;
} else {
    return 0;
}"))
(define-scion clang-regression-test-pointer-dereference14
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference14
                   :patches (list clang-regression-test-pointer-dereference14-patch)))

;; tests from file
;; clang/test/Analysis/diagnostics/macro-null-return-suppression.cpp
(defparameter clang-regression-test-pointer-dereference15-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location x)
                    (and (= (v/value x) 0)
                         (equal "int"
                                (some->> (ast-at-index obj location)
                                         (function-containing-ast obj)
                                         (ast-ret)
                                         (find-type obj)
                                         (type-trace-string)))))
    :free-variables '(("x" "*int"))
    :code "/* POTENTIAL FLAW */
return *x;"))
(define-scion clang-regression-test-pointer-dereference15
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference15
                   :patches (list clang-regression-test-pointer-dereference15-patch)))

;; tests from file
;; clang/test/Analysis/diagnostics/macro-null-return-suppression.cpp
(defparameter clang-regression-test-pointer-dereference16-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location param)
                    (let ((ast (ast-at-index obj location)))
                      (and (= (v/value param) 0)
                           (var-declarable-p obj ast "buf")
                           (equal "int"
                                  (some->> (function-containing-ast obj ast)
                                           (ast-ret)
                                           (find-type obj)
                                           (type-trace-string))))))
    :free-variables '(("param" "*int"))
    :macros (list (make-clang-macro :name "DYN_CAST"
                                    :body "DYN_CAST(X) (X ? (char*)X : 0)"
                                    :hash 0))
    :code "char *param2;
param2 = DYN_CAST(param);
/* POTENTIAL FLAW */
return *param2;"))
(define-scion clang-regression-test-pointer-dereference16
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference16
                   :patches (list clang-regression-test-pointer-dereference16-patch)))

;; tests from file
;; clang/test/Analysis/conditional-path-notes.c
(defparameter clang-regression-test-pointer-dereference17-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (and (= (v/value p) 0)
                         (var-declarable-p obj
                                           (ast-at-index obj location)
                                           "x")))
    :free-variables '(("p" "*int"))
    :code "int *x = p ? p : p;
/* POTENTIAL FLAW */
*x = 1;"))
(define-scion clang-regression-test-pointer-dereference17
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference17
                   :patches (list clang-regression-test-pointer-dereference17-patch)))

;; tests from file
;; clang/test/Analysis/conditional-path-notes.c
(defparameter clang-regression-test-pointer-dereference18-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (and (= (v/value p) 0)
                         (some->> (ast-at-index obj location)
                                  (function-containing-ast obj)
                                  (ast-void-ret))))
    :free-variables '(("p" "*int"))
    :code "if (p) {
    return;
}
/* POTENTIAL FLAW */
int x = *p ? 0 : 1;"))
(define-scion clang-regression-test-pointer-dereference18
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference18
                   :patches (list clang-regression-test-pointer-dereference18-patch)))

;; tests from file
;; clang/test/Analysis/conditional-path-notes.c
(defparameter clang-regression-test-pointer-dereference19-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (and (= (v/value p) 0)
                         (var-declarable-p obj
                                           (ast-at-index obj location)
                                           "x")))
    :free-variables '(("p" "*int"))
    :code "/* POTENTIAL FLAW */
int x = !p ? *p : 1;"))
(define-scion clang-regression-test-pointer-dereference19
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference19
                   :patches (list clang-regression-test-pointer-dereference19-patch)))

;; tests from file
;; clang/test/Analysis/conditional-path-notes.c
(defparameter clang-regression-test-pointer-dereference20-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (and (= (v/value p) 0)
                         (var-declarable-p obj
                                           (ast-at-index obj location)
                                           "x")))
    :free-variables '(("p" "*int"))
    :code "/* POTENTIAL FLAW */
int x = p ? 1 : *p;"))
(define-scion clang-regression-test-pointer-dereference20
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference20
                   :patches (list clang-regression-test-pointer-dereference20-patch)))

;; tests from file
;; clang/test/Analysis/conditional-path-notes.c
(defparameter clang-regression-test-pointer-dereference21-patch
  (make-instance 'clang-dynamic-patch
    :precondition nil
    :free-variables '()
    :code "*(volatile int *)0 = 1;"))
(define-scion clang-regression-test-pointer-dereference21
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference21
                   :patches (list clang-regression-test-pointer-dereference21-patch)))

;; tests from file
;; clang/test/Analysis/html_diagnostics/relevant_lines/goto.c
(defparameter clang-regression-test-pointer-dereference22-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location input)
                    (let ((ast (ast-at-index obj location)))
                      (and (not (= (v/value input) 0))
                           (var-declarable-p obj ast "p")
                           (equal "int"
                                  (some->> (function-containing-ast obj ast)
                                           (ast-ret)
                                           (find-type obj)
                                           (type-trace-string))))))
    :free-variables '(("input" "int"))
    :code "int *p = 0;
if (input)
    goto mylabel;
return 0;
mylabel:
    /* POTENTIAL FLAW */
    return *p;"))
(define-scion clang-regression-test-pointer-dereference22
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference22
                   :patches (list clang-regression-test-pointer-dereference22-patch)))

;; clang/test/Analysis/inlining/path-notes.c
(defparameter clang-regression-test-pointer-dereference23-patch1
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
                    (declare (ignorable obj))
                    (= 0 location))
    :code-top-level-p t
    :code "void zero(int **p) {
    *p = 0;
}"))
(defparameter clang-regression-test-pointer-dereference23-patch2
  (make-instance 'clang-dynamic-patch
    :precondition nil
    :free-variables '(("a" "*int" :-const))
    :dependencies (list clang-regression-test-pointer-dereference23-patch1)
    :code "zero(&a);
/* POTENTIAL FLAW */
*a = 1;"))
(define-scion clang-regression-test-pointer-dereference23
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference23
                   :patches (list clang-regression-test-pointer-dereference23-patch1
                                  clang-regression-test-pointer-dereference23-patch2)))

;; tests from file
;; clang/test/Analysis/inlining/path-notes.c
(defparameter clang-regression-test-pointer-dereference24-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (and (= (v/value p) 0)
                         (some->> (ast-at-index obj location)
                                  (function-containing-ast obj)
                                  (ast-void-ret))))
    :free-variables '(("p" "*int*" :-const))
    :code "if (*p) {
    return;
}
/* POTENTIAL FLAW */
**p = 1;"))
(define-scion clang-regression-test-pointer-dereference24
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference24
                   :patches (list clang-regression-test-pointer-dereference24-patch)))

;; tests from file
;; clang/test/Analysis/test-variably-modified-types.c
(defparameter clang-regression-test-pointer-dereference25-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location x)
                    (and (= (v/value x) 0)
                         (equal "int" (some->> (ast-at-index obj location)
                                               (function-containing-ast obj)
                                               (ast-ret)
                                               (find-type obj)
                                               (type-trace-string)))))
    :free-variables '(("x" "*int*"))
    :code "if (!x) {
    /* POTENTIAL FLAW */
    return **x;
}
return 1;"))
(define-scion clang-regression-test-pointer-dereference25
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference25
                   :patches (list clang-regression-test-pointer-dereference25-patch)))

;; tests from file
;; clang/test/Analysis/diagnostics/no-store-func-path-notes.cpp
(defparameter clang-regression-test-pointer-dereference26-patch1
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
                    (declare (ignorable obj))
                    (= location 0))
    :free-variables nil
    :code-top-level-p t
    :code "void init_in_func(int **x) {
  *x = 0;
}"))
(defparameter clang-regression-test-pointer-dereference26-patch2
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location x)
                    (declare (ignorable x))
                    (let ((ast (ast-at-index obj location)))
                      (and (var-declarable-p obj ast "y")
                           (equal "int" (some->> (function-containing-ast
                                                   obj ast)
                                                 (ast-ret)
                                                 (find-type obj)
                                                 (type-trace-string))))))
    :dependencies (list clang-regression-test-pointer-dereference26-patch1)
    :free-variables '(("x" "int" :-const))
    :code "int *y = &x;
init_in_func(&y);
/* POTENTIAL FLAW */
return *y;"))
(define-scion clang-regression-test-pointer-dereference26
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference26
                   :patches (list clang-regression-test-pointer-dereference26-patch1
                                  clang-regression-test-pointer-dereference26-patch2)))

;; tests from file
;; clang/test/Analysis/plist-macros.cpp
(defparameter clang-regression-test-pointer-dereference27-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (and (= (v/value p) 0)
                         (equal "int" (some->> (ast-at-index obj location)
                                               (function-containing-ast obj)
                                               (ast-ret)
                                               (find-type obj)
                                               (type-trace-string)))))
    :free-variables '(("p" "*int"))
    :macros (list (make-clang-macro :name "macroWithArg"
                                    :body "macroWithArg(mp) mp==0"
                                    :hash 0))
    :code "if (macroWithArg(p))
    ;
/* POTENTIAL FLAW */
return *p;"))
(define-scion clang-regression-test-pointer-dereference27
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference27
                   :patches (list clang-regression-test-pointer-dereference27-patch)))

;; tests from file
;; clang/test/Analysis/pointer-arithmetic.c
;; clang v3.8 doesn't throw warning for this scion
;; but clang 6.0.0 does
(defparameter clang-regression-test-pointer-dereference28-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (declare (ignorable p))
                    (equal "int" (some->> (ast-at-index obj location)
                                          (function-containing-ast obj)
                                          (ast-ret)
                                          (find-type obj)
                                          (type-trace-string))))
    :free-variables '(("p" "*int" :-const))
    :includes '("<stdlib.h>")
    :code "p = (int *) malloc(sizeof(int));
p -= 1;
/* POTENTIAL FLAW */
return *p;"))
(define-scion clang-regression-test-pointer-dereference28
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference28
                   :patches (list clang-regression-test-pointer-dereference28-patch)))

;; tests from file
;; clang/test/Analysis/pointer-arithmetic.c
;; clang v3.8 doesn't throw warning for this scion
;; but clang 6.0.0 does
(defparameter clang-regression-test-pointer-dereference29-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (declare (ignorable p))
                    (equal "int" (some->> (ast-at-index obj location)
                                          (function-containing-ast obj)
                                          (ast-ret)
                                          (find-type obj)
                                          (type-trace-string))))
    :free-variables '(("p" "*int" :-const))
    :includes '("<stdlib.h>")
    :code "p = (int *) malloc(sizeof(int));
p -= 2;
p += 1;
/* POTENTIAL FLAW */
return *p;"))
(define-scion clang-regression-test-pointer-dereference29
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference29
                   :patches (list clang-regression-test-pointer-dereference29-patch)))

;; tests from file
;; clang/test/Analysis/pointer-arithmetic.c
;; clang v3.8 doesn't throw warning for this scion
;; but clang 6.0.0 does
(defparameter clang-regression-test-pointer-dereference30-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (declare (ignorable p))
                    (equal "int" (some->> (ast-at-index obj location)
                                          (function-containing-ast obj)
                                          (ast-ret)
                                          (find-type obj)
                                          (type-trace-string))))
    :free-variables '(("p" "*int" :-const))
    :includes '("<stdlib.h>")
    :code "p = (int *) malloc(sizeof(int));
p++;
p--;
p--;
/* POTENTIAL FLAW */
return *p;"))
(define-scion clang-regression-test-pointer-dereference30
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference30
                   :patches (list clang-regression-test-pointer-dereference30-patch)))

;; tests from file
;; clang/test/Analysis/inlining/false-positive-suppression.c
(defparameter clang-regression-test-pointer-dereference31-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (and (= (v/value p) 0)
                         (var-declarable-p obj (ast-at-index obj location) "i")))
    :free-variables '(("p" "*int" :-const))
    :macros (list (make-clang-macro
                    :name "MACRO_WITH_CHECK"
                    :body "MACRO_WITH_CHECK(a) ( ((a) != 0) ? *a : 17 )"
                    :hash 0))
    :code "int i = MACRO_WITH_CHECK(p);
(void)i;
/* POTENTIAL FLAW */
*p = 1;"))
(define-scion clang-regression-test-pointer-dereference31
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference31
                   :patches (list clang-regression-test-pointer-dereference31-patch)))

;; tests from file
;; clang/test/Analysis/inlining/false-positive-suppression.c
(defparameter clang-regression-test-pointer-dereference32-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (declare (ignorable obj location))
                    (= (v/value p) 0))
    :free-variables '(("p" "*int" :-const))
    :macros (list (make-clang-macro
                    :name "MACRO_WITH_NESTED_CHECK"
                    :body "MACRO_WITH_NESTED_CHECK(a) ( { int j = MACRO_WITH_CHECK(a); j; } )"
                    :hash 1)
                  (make-clang-macro
                    :name "MACRO_WITH_CHECK"
                    :body "MACRO_WITH_CHECK(a) ( ((a) != 0) ? *a : 17)"
                    :hash 0))
    :code "MACRO_WITH_NESTED_CHECK(p);
/* POTENTIAL FLAW */
*p = 1;"))
(define-scion clang-regression-test-pointer-dereference32
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference32
                   :patches (list clang-regression-test-pointer-dereference32-patch)))

;; tests from file
;; clang/test/Analysis/inlining/false-positive-suppression.c
(defparameter clang-regression-test-pointer-dereference33-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (and (= (v/value p) 0)
                            (var-declarable-p obj
                                              (ast-at-index obj location)
                                              "i")))
    :free-variables '(("p" "*int"))
    :macros (list (make-clang-macro
                    :name "MACRO_WITH_ERROR"
                    :body "MACRO_WITH_ERROR(a) ( ((a) != 0) ? 0 : *a)"
                    :hash 0))
    :code "/* POTENTIAL FLAW */
int i = MACRO_WITH_ERROR(p);"))
(define-scion clang-regression-test-pointer-dereference33
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference33
                   :patches (list clang-regression-test-pointer-dereference33-patch)))

;; tests from file
;; clang/test/Analysis/inlining/false-positive-suppression.c
(defparameter clang-regression-test-pointer-dereference34-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (and (= (v/value p) 0)
                            (var-declarable-p obj
                                              (ast-at-index obj location)
                                              "i")))
    :free-variables '(("p" "*int"))
    :macros (list (make-clang-macro
                    :name "MACRO_DO_IT"
                    :body "MACRO_DO_IT(a) (a)"
                    :hash 0))
    :code "/* POTENTIAL FLAW */
int i = MACRO_DO_IT((p ? 0 : *p));"))
(define-scion clang-regression-test-pointer-dereference34
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference34
                   :patches (list clang-regression-test-pointer-dereference34-patch)))

;; tests from file
;; clang/test/Analysis/inlining/false-positive-suppression.c
(defparameter clang-regression-test-pointer-dereference35-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location x)
                    (and (= (v/value x) 0)
                         (equal "int"
                                (some->> (ast-at-index obj location)
                                         (function-containing-ast obj)
                                         (ast-ret)
                                         (find-type obj)
                                         (type-trace-string)))))
    :free-variables '(("x" "int"))
    :includes '("<stdlib.h>")
    :code "/* POTENTIAL FLAW */
return *(x ? 0 : ((int*) malloc(sizeof(int))));"))
(define-scion clang-regression-test-pointer-dereference35
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference35
                   :patches (list clang-regression-test-pointer-dereference35-patch)))

;; tests from file
;; clang/test/Analysis/inlining/false-positive-suppression.c
(defparameter clang-regression-test-pointer-dereference36-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location x)
                    (and (= (v/value x) 0)
                         (equal "int"
                                (some->> (ast-at-index obj location)
                                         (function-containing-ast obj)
                                         (ast-ret)
                                         (find-type obj)
                                         (type-trace-string)))))
    :free-variables '(("x" "int"))
    :includes '("<stdlib.h>")
    :code "/* POTENTIAL FLAW */
return *(x ? 0 : ((int*) malloc(sizeof(int))));"))
(define-scion clang-regression-test-pointer-dereference36
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference36
                   :patches (list clang-regression-test-pointer-dereference36-patch)))

;; tests from file
;; clang/test/Analysis/inlining/false-positive-suppression.c
(defparameter clang-regression-test-pointer-dereference37-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location p)
                    (declare (ignorable obj location))
                    (= (v/value p) 0))
    :free-variables '(("p" "*int"))
    :macros (list (make-clang-macro :name "DEREF"
                                    :body "DEREF(p) *p = 0xDEADBEEF"
                                    :hash 0))
    :code "/* POTENTIAL FLAW */
DEREF(p);"))
(define-scion clang-regression-test-pointer-dereference37
    (make-instance 'clang-scion
                   :name 'clang-regression-test-pointer-dereference37
                   :patches (list clang-regression-test-pointer-dereference37-patch)))

;; tests from file clang/test/Analysis/malloc-annotations.c
(defparameter clang-regression-test-buffer1-patch
  (make-instance 'clang-dynamic-patch
    :precondition nil
    :free-variables '(("buf" "*char" :-const))
    :includes '("<stdlib.h>")
    :code "buf = (char*) malloc(2);
/* POTENTIAL FLAW */
buf[1] = 'c';"))
(define-scion clang-regression-test-buffer1
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer1
                   :patches (list clang-regression-test-buffer1-patch)))

;; tests from file clang/test/Analysis/outofbound.c
(defparameter clang-regression-test-buffer2-patch
  (make-instance 'clang-dynamic-patch
    :precondition nil
    :free-variables '(("p" "*int" :-const))
    :includes '("<stdlib.h>")
    :code "p = (int*) malloc(12);
/* POTENTIAL FLAW */
p[3] = 4;"))
(define-scion clang-regression-test-buffer2
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer2
                   :patches (list clang-regression-test-buffer2-patch)))

;; tests from file clang/test/Analysis/outofbound.c
(defparameter clang-regression-test-buffer3-patch
  (make-instance 'clang-dynamic-patch
    :precondition nil
    :free-variables '(("p" "*char" :-const))
    :includes '("<stdlib.h>")
    :code "p = (char*) calloc(2,2);
p[3] = '.';
/* POTENTIAL FLAW */
p[4] = '!';"))
(define-scion clang-regression-test-buffer3
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer3
                   :patches (list clang-regression-test-buffer3-patch)))

;; tests from file clang/test/Analysis/outofbound.c
(defparameter clang-regression-test-buffer4-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (vars-declarable-p obj
                                       (ast-at-index obj location)
                                       '("a" "b")))
    :free-variables '()
    :code "char a[2];
int *b = (int*)a;
/* POTENTIAL FLAW */
b[1] = 3;"))
(define-scion clang-regression-test-buffer4
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer4
                   :patches (list clang-regression-test-buffer4-patch)))

;; tests from file clang/test/Analysis/outofbound.c
(defparameter clang-regression-test-buffer5-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location a)
                    (declare (ignorable obj location))
                    (= (v/value a) 5))
    :free-variables '(("a" "int"))
    :code "if (a == 5) {
    int x[a];
    x[4] = 4;
    /* POTENTIAL FLAW */
    x[5] = 5;
}"))
(define-scion clang-regression-test-buffer5
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer5
                   :patches (list clang-regression-test-buffer5-patch)))

;; tests from file clang/test/Analysis/outofbound.c
(defparameter clang-regression-test-buffer6-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location a)
                    (let ((ast (ast-at-index obj location)))
                      (and (= (v/value a) 2)
                           (equal "int"
                                  (some->> (function-containing-ast obj ast)
                                           (ast-ret)
                                           (find-type obj)
                                           (type-trace-string)))
                           (var-declarable-p obj ast "x"))))
    :free-variables '(("a" "int"))
    :code "int x[2];
if (a == 2) {
    /* POTENTIAL FLAW */
    return x[a];
}"))
(define-scion clang-regression-test-buffer6
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer6
                   :patches (list clang-regression-test-buffer6-patch)))

;; tests from file clang/test/Analysis/outofbound.c
(defparameter clang-regression-test-buffer7-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location a)
                    (let ((ast (ast-at-index obj location)))
                      (and (< (v/value a) 0)
                           (equal "int"
                                  (some->> (function-containing-ast obj ast)
                                           (ast-ret)
                                           (find-type obj)
                                           (type-trace-string)))
                           (var-declarable-p obj ast "x"))))
    :free-variables '(("a" "int"))
    :code "int x[2];
if (a < 0) {
    /* POTENTIAL FLAW */
    return x[a];
}"))
(define-scion clang-regression-test-buffer7
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer7
                   :patches (list clang-regression-test-buffer7-patch)))

;; tests from file clang/test/Analysis/outofbound.c
(defparameter clang-regression-test-buffer8-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location in)
                     (and (> (v/value in) 1E-8)
                          (< (v/value in) 1E+23)
                          (var-declarable-p obj
                                            (ast-at-index obj location)
                                            "eee")))
    :free-variables '(("in" "double"))
    :code "int eee = 16;
  if (in < 1e-8 || in > 1e23) {
    return 0;
  } else {
    static const double ins[] = {1e-8, 1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2,
                                 1e-1, 1e0, 1e1, 1e2, 1e3, 1e4, 1e5, 1e6, 1e7,
                                 1e8, 1e9, 1e10, 1e11, 1e12, 1e13, 1e14, 1e15,
                                 1e16, 1e17, 1e18, 1e19, 1e20, 1e21, 1e22};
    if (in < ins[eee]) {
      eee -= 8;
    } else {
      eee += 8;
    }
    if (in < ins[eee]) {
      eee -= 4;
    } else {
      eee += 4;
    }
    if (in < ins[eee]) {
      eee -= 2;
    } else {
      eee += 2;
    }
    if (in < ins[eee]) {
      eee -= 1;
    } else {
      eee += 1;
    }
    /* POTENTIAL FLAW */
    if (in < ins[eee]) { //Access out-of-bound array element (buffer overflow)
      eee -= 1;
    }
  }
  return eee;"))
(define-scion clang-regression-test-buffer8
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer8
                   :patches (list clang-regression-test-buffer8-patch)))

;; tests from file clang/test/Analysis/cstring-syntax.c
(defparameter clang-regression-test-buffer9-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (var-declarable-p obj (ast-at-index obj location) "dest"))
    :free-variables '()
    :includes '("<string.h>")
    :code "char dest[10];
/* POTENTIAL FLAW */
strncat(dest, \"AAAAAAAAAAAAAAAAAAAAAAAAAAAAA\", sizeof(dest) - 1);"))
(define-scion clang-regression-test-buffer9
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer9
                   :patches (list clang-regression-test-buffer9-patch)))

;; tests from file clang/test/Analysis/cstring-syntax.c
(defparameter clang-regression-test-buffer10-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (var-declarable-p obj (ast-at-index obj location) "dest"))
    :free-variables '()
    :includes '("<string.h>")
    :code "char dest[10];
/* POTENTIAL FLAW */
strncat(dest, \"AAAAAAAAAAAAAAAAAAAAAAAAAAA\", sizeof(dest));"))
(define-scion clang-regression-test-buffer10
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer10
                   :patches (list clang-regression-test-buffer10-patch)))

;; tests from file clang/test/Analysis/cstring-syntax.c
(defparameter clang-regression-test-buffer11-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (var-declarable-p obj (ast-at-index obj location) "dest"))
    :free-variables '()
    :includes '("<string.h>")
    :code "char dest[10];
/* POTENTIAL FLAW */
strncat(dest, \"AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA\",
        sizeof(dest) - strlen(dest));"))
(define-scion clang-regression-test-buffer11
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer11
                   :patches (list clang-regression-test-buffer11-patch)))

;; tests from file clang/test/Analysis/out-of-bounds.c
(defparameter clang-regression-test-buffer12-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (let ((ast (ast-at-index obj location)))
                      (and (var-declarable-p obj ast "mystr")
                           (string= "char"
                                    (some->> (function-containing-ast obj ast)
                                             (ast-ret)
                                             (find-type obj)
                                             (type-trace-string))))))
    :free-variables '()
    :code "const char *mystr = \"mary had a little lamb\";
/* POTENTIAL FLAW */
return mystr[-1];"))
(define-scion clang-regression-test-buffer12
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer12
                   :patches (list clang-regression-test-buffer12-patch)))

;; tests from file clang/test/Analysis/out-of-bounds.c
(defparameter clang-regression-test-buffer13-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (let ((ast (ast-at-index obj location)))
                      (and (var-declarable-p obj ast "mystr")
                           (string= "char"
                                    (some->> (function-containing-ast obj ast)
                                             (ast-ret)
                                             (find-type obj)
                                             (type-trace-string))))))
    :free-variables '()
    :code "const char *mystr = \"mary had a little lamb\";
/* POTENTIAL FLAW */
return mystr[1000]; "))
(define-scion clang-regression-test-buffer13
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer13
                   :patches (list clang-regression-test-buffer13-patch)))

;; tests from file clang/test/Analysis/out-of-bounds.c
(defparameter clang-regression-test-buffer14-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (vars-declarable-p obj
                                       (ast-at-index obj location)
                                       '("buf" "p")))
    :free-variables '()
    :code "int buf[100];
int *p = buf;
/* POTENTIAL FLAW */
p[101] = 1; "))
(define-scion clang-regression-test-buffer14
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer14
                   :patches (list clang-regression-test-buffer14-patch)))

;; tests from file clang/test/Analysis/out-of-bounds.c
(defparameter clang-regression-test-buffer15-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (vars-declarable-p obj
                                       (ast-at-index obj location)
                                      '("buf" "p")))
    :free-variables '()
    :code "int buf[100];
int *p = buf;
/* POTENTIAL FLAW */
p[-1] = 1;"))
(define-scion clang-regression-test-buffer15
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer15
                   :patches (list clang-regression-test-buffer15-patch)))

;; tests from file clang/test/Analysis/out-of-bounds.c
(defparameter clang-regression-test-buffer16-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location)
                    (vars-declarable-p obj
                                       (ast-at-index obj location)
                                       '("buf" "p")))
    :free-variables '()
    :code "int buf[100];
int *p = buf;
--p;
/* POTENTIAL FLAW */
p[0] = 1;"))
(define-scion clang-regression-test-buffer16
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer16
                   :patches (list clang-regression-test-buffer16-patch)))

;; tests from file clang/test/Analysis/out-of-bounds.c
(defparameter clang-regression-test-buffer17-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location x)
                    (and (> (v/value x) 99)
                         (var-declarable-p obj
                                           (ast-at-index obj location)
                                           "buf")))
    :free-variables '(("x" "int"))
    :code "int buf[100];
if (x > 99) {
    /* POTENTIAL FLAW */
    buf[x] = 1;
}"))
(define-scion clang-regression-test-buffer17
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer17
                   :patches (list clang-regression-test-buffer17-patch)))

;; tests from file clang/test/Analysis/out-of-bounds.c
(defparameter clang-regression-test-buffer18-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location x)
                    (and (< (v/value x) 0)
                         (var-declarable-p obj
                                           (ast-at-index obj location)
                                           "buf")))
    :free-variables '(("x" "int"))
    :code "int buf[100];
if (x < 0) {
    /* POTENTIAL FLAW */
    buf[x] = 1;
}"))
(define-scion clang-regression-test-buffer18
    (make-instance 'clang-scion
                   :name 'clang-regression-test-buffer18
                   :patches (list clang-regression-test-buffer18-patch)))

;; Infer regression tests
;; tests from file infer/tests/codetoanalyze/c/bufferoverrun/global.c
(defparameter infer-regression-test-buffer1-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location global)
                    (and (< (v/value global) 10)
                            (var-declarable-p obj
                                              (ast-at-index obj location)
                                              "arr")))
    :free-variables '(("global" "int"))
    :code "char arr[10];
if (global < 10){
    /* POTENTIAL FLAW */
    arr[10] = 1;
}"))
(define-scion infer-regression-test-buffer1
    (make-instance 'clang-scion
                   :name 'infer-regression-test-buffer1
                   :patches (list infer-regression-test-buffer1-patch)))

;; tests from file infer/tests/codetoanalyze/c/bufferoverrun/duplicates.c
(defparameter infer-regression-test-buffer2-patch1
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
                    (declare (ignorable obj))
                    (= location 0))
    :free-variables '()
    :code-top-level-p t
    :code "void two_accesses(int* arr) {
    if (arr[1] < 0) {
        arr[0] = 0;
    }
}"))

(defparameter infer-regression-test-buffer2-patch2
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location arr)
                    (declare (ignorable obj location))
                    (and (v/size arr)
                         (<= (v/size arr) 4)))
    :free-variables '(("arr" "*int" :-const))
    :dependencies (list infer-regression-test-buffer2-patch1)
    :code "/* POTENTIAL FLAW */
two_accesses(arr);"))
(define-scion infer-regression-test-buffer2
    (make-instance 'clang-scion
                   :name 'infer-regression-test-buffer2
                   :patches (list infer-regression-test-buffer2-patch1
                                  infer-regression-test-buffer2-patch2)))

;; tests from file infer/tests/codetoanalyze/c/bufferoverrun/duplicates.c
(defparameter infer-regression-test-buffer3-patch
  (make-instance 'clang-dynamic-patch
    :precondition (lambda (obj location n)
                    (and (= (v/value n) 0)
                         (var-declarable-p obj
                                           (ast-at-index obj location)
                                           "arr")))
    :free-variables '(("n" "int"))
    :code "int arr[1];
arr[n] = 0;
/* POTENTIAL FLAW */
arr[n - 2] = 0;"))
(define-scion infer-regression-test-buffer3
    (make-instance 'clang-scion
                   :name 'infer-regression-test-buffer3
                   :patches (list infer-regression-test-buffer3-patch)))

;; tests from file infer/tests/codetoanalyze/c/biabduction/abduce.c
(defparameter infer-regression-test-pointer-dereference1-patch1
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
                    (declare (ignorable obj))
                    (= location 0))
    :code-top-level-p t
    :code "void set_ptr(int* ptr, int val) {
    *ptr = val;
}
int set_ptr_param_array(int buf[]) {
    set_ptr(buf, 1);
    return buf[0];
}"))
(defparameter infer-regression-test-pointer-dereference1-patch2
  (make-instance 'clang-dynamic-patch
    :dependencies (list infer-regression-test-pointer-dereference1-patch1)
    :code "/* POTENTIAL FLAW */
set_ptr_param_array(0);"))
(define-scion infer-regression-test-pointer-dereference1
    (make-instance 'clang-scion
                   :name 'infer-regression-test-pointer-dereference1
                   :patches (list infer-regression-test-pointer-dereference1-patch1
                                  infer-regression-test-pointer-dereference1-patch2)))

(defvar printLine_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "printLine" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdio.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1944158543856436560 :I-FILE NIL :POINTER T :CONST T :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS ("line" -1944158543856436560)) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "printLine") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL . T) (:MACROS) (:NAME . "printLine") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void printLine (\"" (((:ARGS) (:CLASS . "PARMVAR") (:COUNTER . 2) (:DECLARES "line") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1944158543856436560) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"const char * line\"") "\")\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 4) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|line|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"%s\\\\n\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|line|)\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n}\"") "\"\""))))


(defvar CWE121_Stack_Based_Buffer_Overflow__CWE193_char_alloca_cpy_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE121_Stack_Based_Buffer_Overflow__CWE193_char_alloca_cpy_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<alloca.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[11]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 2944235125889796353 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 11) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -4911426765191714778 :NAME "SRC_STRING" :BODY "SRC_STRING \"AAAAAAAAAA\"") #S(CLANG-MACRO :HASH -342517378131665086 :NAME "ALLOCA" :BODY "ALLOCA alloca"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE121_Stack_Based_Buffer_Overflow__CWE193_char_alloca_cpy_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>" "<string.h>") (:IS-DECL . T) (:MACROS -4911426765191714778) (:NAME . "CWE121_Stack_Based_Buffer_Overflow__CWE193_char_alloca_cpy_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE121_Stack_Based_Buffer_Overflow__CWE193_char_alloca_cpy_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>" "<string.h>") (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 5) (:DECLARES "dataBadBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 6) (:DECLARES "dataBadBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727 -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataBadBuffer = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA((10)*sizeof(char))\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 16) (:DECLARES "dataGoodBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 17) (:DECLARES "dataGoodBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727 -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataGoodBuffer = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA((10+1)*sizeof(char))\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n    \\/* FLAW: Set a pointer to a buffer that does not leave room for a NULL terminator when performing\\r\\n     * string copies in the sinks  *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBadBuffer|)\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 41) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 42) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 2944235125889796353) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char source[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"10\"") "\"+\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"] = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"SRC_STRING\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: data may not have enough space to hold source *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE121_Stack_Based_Buffer_Overflow__CWE193_char_alloca_cpy_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBadBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA((10)*sizeof(char))\"") "\"\"")) . (equal (v/size dataBadBuffer) 10)))
    :free-variables '(("data" "*char" :-CONST :-REGISTER) ("dataBadBuffer" "*char" :-CONST :-REGISTER) ("dataGoodBuffer" "*char" :-CONST :-REGISTER))
    :includes '("<alloca.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[11]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 2944235125889796353 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 11) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -4911426765191714778 :NAME "SRC_STRING" :BODY "SRC_STRING \"AAAAAAAAAA\"") #S(CLANG-MACRO :HASH -342517378131665086 :NAME "ALLOCA" :BODY "ALLOCA alloca"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBadBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA((10)*sizeof(char))\"") "\"\"")) (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataGoodBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA((10+1)*sizeof(char))\"") "\"\"")) (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBadBuffer|)\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 41) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 42) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 2944235125889796353) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char source[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"10\"") "\"+\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"] = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"SRC_STRING\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: data may not have enough space to hold source *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE121_Stack_Based_Buffer_Overflow__CWE193_char_alloca_cpy_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE121_Stack_Based_Buffer_Overflow__CWE193_char_alloca_cpy_01_bad_top_level_inline
    :patches (list printLine_patch CWE121_Stack_Based_Buffer_Overflow__CWE193_char_alloca_cpy_01_bad_top_level_inline_patch)))

(defvar CWE122_Heap_Based_Buffer_Overflow__c_CWE193_char_cpy_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE122_Heap_Based_Buffer_Overflow__c_CWE193_char_cpy_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[11]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 2944235125889796353 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 11) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -4911426765191714778 :NAME "SRC_STRING" :BODY "SRC_STRING \"AAAAAAAAAA\""))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE122_Heap_Based_Buffer_Overflow__c_CWE193_char_cpy_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL . T) (:MACROS -4911426765191714778) (:NAME . "CWE122_Heap_Based_Buffer_Overflow__c_CWE193_char_cpy_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE122_Heap_Based_Buffer_Overflow__c_CWE193_char_cpy_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\";\\r\\n    \\/* FLAW: Did not leave space for a null terminator *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"10\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 36) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 37) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 2944235125889796353) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char source[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"10\"") "\"+\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"] = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"SRC_STRING\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: data may not have enough space to hold source *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE122_Heap_Based_Buffer_Overflow__c_CWE193_char_cpy_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"10\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\"\"") "\"\"") . (equal (v/size data) 10)))
    :free-variables '(("data" "*char" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[11]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 2944235125889796353 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 11) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -4911426765191714778 :NAME "SRC_STRING" :BODY "SRC_STRING \"AAAAAAAAAA\""))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"10\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 36) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 37) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 2944235125889796353) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char source[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"10\"") "\"+\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"] = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -4911426765191714778) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"SRC_STRING\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: data may not have enough space to hold source *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE122_Heap_Based_Buffer_Overflow__c_CWE193_char_cpy_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE122_Heap_Based_Buffer_Overflow__c_CWE193_char_cpy_01_bad_top_level_inline
    :patches (list printLine_patch CWE122_Heap_Based_Buffer_Overflow__c_CWE193_char_cpy_01_bad_top_level_inline_patch)))

(defvar CWE124_Buffer_Underwrite__char_alloca_cpy_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE124_Buffer_Underwrite__char_alloca_cpy_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<alloca.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -342517378131665086 :NAME "ALLOCA" :BODY "ALLOCA alloca"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE124_Buffer_Underwrite__char_alloca_cpy_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>" "<string.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE124_Buffer_Underwrite__char_alloca_cpy_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE124_Buffer_Underwrite__char_alloca_cpy_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 5) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 6) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727 -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataBuffer = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(100*sizeof(char))\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'A'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n    \\/* FLAW: Set data pointer to before the allocated memory buffer *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\" - \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"8\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 42) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 43) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char source[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"]\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'C'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\"; \\/* fill with 'C's *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n        \\/* POTENTIAL FLAW: Possibly copying data to memory before the destination buffer *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE124_Buffer_Underwrite__char_alloca_cpy_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(100*sizeof(char))\"") "\"\"")) . (equal (v/size dataBuffer) 100)))
    :free-variables '(("data" "*char" :-CONST :-REGISTER) ("dataBuffer" "*char" :-CONST :-REGISTER))
    :includes '("<alloca.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -342517378131665086 :NAME "ALLOCA" :BODY "ALLOCA alloca"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(100*sizeof(char))\"") "\"\"")) (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'A'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\" - \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"8\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 42) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 43) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char source[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"]\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'C'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\"; \\/* fill with 'C's *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n        \\/* POTENTIAL FLAW: Possibly copying data to memory before the destination buffer *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE124_Buffer_Underwrite__char_alloca_cpy_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE124_Buffer_Underwrite__char_alloca_cpy_01_bad_top_level_inline
    :patches (list printLine_patch CWE124_Buffer_Underwrite__char_alloca_cpy_01_bad_top_level_inline_patch)))

(defvar CWE126_Buffer_Overread__char_alloca_loop_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE126_Buffer_Overread__char_alloca_loop_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<alloca.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100) #S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/home/jruchti/synth/bin/../lib/clang/6.0.1/include/stddef.h" :LINE 62 :HASH 764611252874068922 :I-FILE "<stddef.h>" :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "size_t" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -342517378131665086 :NAME "ALLOCA" :BODY "ALLOCA alloca"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE126_Buffer_Overread__char_alloca_loop_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>" "<string.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE126_Buffer_Overread__char_alloca_loop_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE126_Buffer_Overread__char_alloca_loop_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 5) (:DECLARES "dataBadBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 6) (:DECLARES "dataBadBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727 -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataBadBuffer = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(50*sizeof(char))\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 15) (:DECLARES "dataGoodBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 16) (:DECLARES "dataGoodBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727 -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataGoodBuffer = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(100*sizeof(char))\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBadBuffer|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'A'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"50\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\"; \\/* fill with 'A's *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBadBuffer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"50\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataGoodBuffer|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'A'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\"; \\/* fill with 'A's *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataGoodBuffer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n    \\/* FLAW: Set data pointer to a small buffer *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBadBuffer|)\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 70) (:DECLARES "i" "destLen") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 71) (:DECLARES "i") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "LISTELT") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"size_t i\"") "\", \"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 72) (:DECLARES "destLen") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FINALLISTELT") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"destLen\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 73) (:DECLARES "dest") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 74) (:DECLARES "dest") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char dest[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"]\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'C'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 85) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 86) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 87) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 88) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 89) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 90) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 91) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 92) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 93) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 94) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 95) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 96) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 97) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|destLen|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 98) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 99) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 100) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 101) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 102) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 103) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: using length of the dest where data\\r\\n         * could be smaller than dest causing buffer overread *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "FORSTMT") (:COUNTER . 104) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"for (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 105) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 106) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 107) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 108) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 109) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 110) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 111) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\" < \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 112) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 113) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|destLen|)\"") "\"\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 114) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "++") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 115) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"++\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 116) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 117) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 118) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 119) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 120) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 121) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 122) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 123) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 124) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 125) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 126) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 127) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 128) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\"]\"") "\"\"") "\"\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 129) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 130) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 131) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 132) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 133) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 134) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 135) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 136) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 137) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 138) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 139) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 140) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 141) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 142) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 143) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE126_Buffer_Overread__char_alloca_loop_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBadBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(50*sizeof(char))\"") "\"\"")) . (equal (v/size dataBadBuffer) 50))((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataGoodBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(100*sizeof(char))\"") "\"\"")) . (equal (v/size dataGoodBuffer) 100)))
    :free-variables '(("data" "*char" :-CONST :-REGISTER) ("dataBadBuffer" "*char" :-CONST :-REGISTER) ("dataGoodBuffer" "*char" :-CONST :-REGISTER))
    :includes '("<alloca.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100) #S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/home/jruchti/synth/bin/../lib/clang/6.0.1/include/stddef.h" :LINE 62 :HASH 764611252874068922 :I-FILE "<stddef.h>" :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "size_t" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -342517378131665086 :NAME "ALLOCA" :BODY "ALLOCA alloca"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBadBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(50*sizeof(char))\"") "\"\"")) (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataGoodBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(100*sizeof(char))\"") "\"\"")) (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBadBuffer|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'A'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"50\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBadBuffer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"50\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataGoodBuffer|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'A'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataGoodBuffer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBadBuffer|)\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 70) (:DECLARES "i" "destLen") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 71) (:DECLARES "i") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "LISTELT") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"size_t i\"") "\", \"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 72) (:DECLARES "destLen") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FINALLISTELT") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"destLen\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 73) (:DECLARES "dest") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 74) (:DECLARES "dest") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char dest[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"]\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'C'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 85) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 86) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 87) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 88) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 89) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 90) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 91) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 92) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 93) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 94) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 95) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 96) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 97) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|destLen|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 98) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 99) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 100) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 101) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 102) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 103) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: using length of the dest where data\\r\\n         * could be smaller than dest causing buffer overread *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "FORSTMT") (:COUNTER . 104) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"for (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 105) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 106) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 107) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 108) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 109) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 110) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 111) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\" < \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 112) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 113) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|destLen|)\"") "\"\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 114) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "++") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 115) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"++\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 116) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 117) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 118) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 119) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 120) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 121) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 122) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 123) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 124) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 125) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 126) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 127) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 128) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\"]\"") "\"\"") "\"\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 129) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 130) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 131) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 132) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 133) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 134) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 135) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 136) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 137) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 138) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 139) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 140) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 141) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 142) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 143) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE126_Buffer_Overread__char_alloca_loop_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE126_Buffer_Overread__char_alloca_loop_01_bad_top_level_inline
    :patches (list printLine_patch CWE126_Buffer_Overread__char_alloca_loop_01_bad_top_level_inline_patch)))

(defvar CWE127_Buffer_Underread__char_alloca_cpy_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE127_Buffer_Underread__char_alloca_cpy_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<alloca.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[200]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 349279012212144110 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 200) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -342517378131665086 :NAME "ALLOCA" :BODY "ALLOCA alloca"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE127_Buffer_Underread__char_alloca_cpy_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>" "<string.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE127_Buffer_Underread__char_alloca_cpy_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE127_Buffer_Underread__char_alloca_cpy_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 5) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 6) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727 -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataBuffer = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(100*sizeof(char))\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'A'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n    \\/* FLAW: Set data pointer to before the allocated memory buffer *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\" - \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"8\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 42) (:DECLARES "dest") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 43) (:DECLARES "dest") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 349279012212144110) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char dest[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"*\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"\"") "\"]\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'C'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"*\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\"; \\/* fill with 'C's *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"*\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n        \\/* POTENTIAL FLAW: Possibly copy from a memory location located before the source buffer *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE127_Buffer_Underread__char_alloca_cpy_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(100*sizeof(char))\"") "\"\"")) . (equal (v/size dataBuffer) 100)))
    :free-variables '(("data" "*char" :-CONST :-REGISTER) ("dataBuffer" "*char" :-CONST :-REGISTER))
    :includes '("<alloca.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[200]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 349279012212144110 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 200) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -342517378131665086 :NAME "ALLOCA" :BODY "ALLOCA alloca"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(100*sizeof(char))\"") "\"\"")) (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'A'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\" - \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"8\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 42) (:DECLARES "dest") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 43) (:DECLARES "dest") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 349279012212144110) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char dest[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"*\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"\"") "\"]\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'C'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"*\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\"; \\/* fill with 'C's *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"*\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n        \\/* POTENTIAL FLAW: Possibly copy from a memory location located before the source buffer *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE127_Buffer_Underread__char_alloca_cpy_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE127_Buffer_Underread__char_alloca_cpy_01_bad_top_level_inline
    :patches (list printLine_patch CWE127_Buffer_Underread__char_alloca_cpy_01_bad_top_level_inline_patch)))

(defvar printIntLine_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "printIntLine" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdio.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS ("intNumber" -1958391046879680490)) (:CLASS . "FUNCTION") (:COUNTER . 41) (:DECLARES "printIntLine") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL . T) (:MACROS) (:NAME . "printIntLine") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void printIntLine (\"" (((:ARGS) (:CLASS . "PARMVAR") (:COUNTER . 42) (:DECLARES "intNumber") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int intNumber\"") "\")\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"%d\\\\n\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intNumber|)\"") "\"\"") "\")\"") "\";\\r\\n}\"") "\"\""))))


(defvar CWE190_Integer_Overflow__int_rand_add_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE190_Integer_Overflow__int_rand_add_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE190_Integer_Overflow__int_rand_add_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE190_Integer_Overflow__int_rand_add_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE190_Integer_Overflow__int_rand_add_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int data\"") "\"\"") "\";\\r\\n    \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Set data to a random value *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* POTENTIAL FLAW: Adding 1 to data could cause an overflow *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 66) (:DECLARES "result") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 67) (:DECLARES "result") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int result = \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" + \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|result|)\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE190_Integer_Overflow__int_rand_add_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") . (equal (v/value data) -270348886)))
    :free-variables '(("data" "int" :-CONST :-REGISTER))
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* POTENTIAL FLAW: Adding 1 to data could cause an overflow *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 66) (:DECLARES "result") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 67) (:DECLARES "result") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int result = \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" + \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|result|)\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE190_Integer_Overflow__int_rand_add_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE190_Integer_Overflow__int_rand_add_01_bad_top_level_inline
    :patches (list printIntLine_patch CWE190_Integer_Overflow__int_rand_add_01_bad_top_level_inline_patch)))

(defvar CWE191_Integer_Underflow__int_rand_multiply_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE191_Integer_Underflow__int_rand_multiply_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE191_Integer_Underflow__int_rand_multiply_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE191_Integer_Underflow__int_rand_multiply_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE191_Integer_Underflow__int_rand_multiply_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int data\"") "\"\"") "\";\\r\\n    \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Set data to a random value *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" < \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{ \\/* ensure we won't have an overflow *\\/\\r\\n        \\/* POTENTIAL FLAW: if (data * 2) < INT_MIN, this will underflow *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 71) (:DECLARES "result") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 72) (:DECLARES "result") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int result = \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" * \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|result|)\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE191_Integer_Underflow__int_rand_multiply_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") . (equal (v/value data) -1188111028)))
    :free-variables '(("data" "int" :-CONST :-REGISTER))
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" < \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{ \\/* ensure we won't have an overflow *\\/\\r\\n        \\/* POTENTIAL FLAW: if (data * 2) < INT_MIN, this will underflow *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 71) (:DECLARES "result") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 72) (:DECLARES "result") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int result = \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" * \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|result|)\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\""))))


(define-scion CWE191_Integer_Underflow__int_rand_multiply_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE191_Integer_Underflow__int_rand_multiply_01_bad_top_level_inline
    :patches (list printIntLine_patch CWE191_Integer_Underflow__int_rand_multiply_01_bad_top_level_inline_patch)))

(defvar CWE195_Signed_to_Unsigned_Conversion_Error__rand_malloc_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE195_Signed_to_Unsigned_Conversion_Error__rand_malloc_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE195_Signed_to_Unsigned_Conversion_Error__rand_malloc_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE195_Signed_to_Unsigned_Conversion_Error__rand_malloc_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE195_Signed_to_Unsigned_Conversion_Error__rand_malloc_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int data\"") "\"\"") "\";\\r\\n    \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Set data to a random value *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") "\";\\r\\n    \\/* Assume we want to allocate a relatively small buffer *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" < \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* POTENTIAL FLAW: malloc() takes a size_t (unsigned int) as input and therefore if it is negative,\\r\\n         * the conversion will cause malloc() to allocate a very large amount of data or fail *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 72) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 73) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataBuffer = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 85) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 89) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 90) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 91) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 92) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 93) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 94) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \\/* Do something with dataBuffer *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 95) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 96) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 97) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 98) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 99) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 100) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 101) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'A'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 102) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 103) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 104) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 105) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 106) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 107) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 108) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 109) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 110) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 111) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 112) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 113) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 114) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 115) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 116) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 117) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 118) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 119) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 120) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 121) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 122) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 123) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 124) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 125) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 126) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 127) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 128) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE195_Signed_to_Unsigned_Conversion_Error__rand_malloc_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") . (equal (v/value data) -1663264764)))
    :free-variables '(("data" "int" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" < \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* POTENTIAL FLAW: malloc() takes a size_t (unsigned int) as input and therefore if it is negative,\\r\\n         * the conversion will cause malloc() to allocate a very large amount of data or fail *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 72) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 73) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataBuffer = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 85) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 89) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 90) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 91) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 92) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 93) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 94) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \\/* Do something with dataBuffer *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 95) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 96) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 97) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 98) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 99) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 100) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 101) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'A'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 102) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 103) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 104) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 105) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 106) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 107) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 108) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 109) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 110) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 111) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 112) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 113) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 114) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 115) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 116) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 117) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 118) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 119) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 120) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 121) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 122) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 123) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 124) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 125) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 126) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 127) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 128) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\""))))


(define-scion CWE195_Signed_to_Unsigned_Conversion_Error__rand_malloc_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE195_Signed_to_Unsigned_Conversion_Error__rand_malloc_01_bad_top_level_inline
    :patches (list printLine_patch CWE195_Signed_to_Unsigned_Conversion_Error__rand_malloc_01_bad_top_level_inline_patch)))

(defvar CWE196_Unsigned_to_Signed_Conversion_Error__basic_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE196_Unsigned_to_Signed_Conversion_Error__basic_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<limits.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE196_Unsigned_to_Signed_Conversion_Error__basic_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>" "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE196_Unsigned_to_Signed_Conversion_Error__basic_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE196_Unsigned_to_Signed_Conversion_Error__basic_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "intUnsigned") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "intUnsigned") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"unsigned intUnsigned\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 6) (:DECLARES "intSigned") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 7) (:DECLARES "intSigned") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int intSigned\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intUnsigned|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intUnsigned|)\"") "\" = \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"UINT_MAX\"") "\" - \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intUnsigned|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \\/* FLAW: intUnsigned could be very large, in which case intSigned will be negative *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intSigned|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intUnsigned|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intSigned|)\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE196_Unsigned_to_Signed_Conversion_Error__basic_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intUnsigned|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\"\"") "\"\"") . (equal (v/value intUnsigned) 312092996)))
    :free-variables '(("intUnsigned" "unsigned int" :-CONST :-REGISTER) ("intSigned" "int" :-CONST :-REGISTER))
    :includes '("<limits.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" "\"\\r\\n        \"" "\"\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intUnsigned|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intUnsigned|)\"") "\" = \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"UINT_MAX\"") "\" - \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intUnsigned|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \\/* FLAW: intUnsigned could be very large, in which case intSigned will be negative *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intSigned|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intUnsigned|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intSigned|)\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE196_Unsigned_to_Signed_Conversion_Error__basic_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE196_Unsigned_to_Signed_Conversion_Error__basic_01_bad_top_level_inline
    :patches (list printIntLine_patch CWE196_Unsigned_to_Signed_Conversion_Error__basic_01_bad_top_level_inline_patch)))

(defvar printHexCharLine_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "printHexCharLine" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdio.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1))
    :macros 'NIL
    :code '((((:ARGS ("charHex" -2054504279541534951)) (:CLASS . "FUNCTION") (:COUNTER . 109) (:DECLARES "printHexCharLine") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL . T) (:MACROS) (:NAME . "printHexCharLine") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void printHexCharLine (\"" (((:ARGS) (:CLASS . "PARMVAR") (:COUNTER . 110) (:DECLARES "charHex") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char charHex\"") "\")\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 111) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 112) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 113) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 114) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 115) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 116) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 117) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"%02x\\\\n\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 118) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 119) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 120) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charHex|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n}\"") "\"\""))))


(defvar CWE197_Numeric_Truncation_Error__int_rand_to_char_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE197_Numeric_Truncation_Error__int_rand_to_char_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE197_Numeric_Truncation_Error__int_rand_to_char_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE197_Numeric_Truncation_Error__int_rand_to_char_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE197_Numeric_Truncation_Error__int_rand_to_char_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int data\"") "\"\"") "\";\\r\\n    \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Set data to a random value *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* POTENTIAL FLAW: Convert data to a char, possibly causing a truncation error *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 67) (:DECLARES "charData") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 68) (:DECLARES "charData") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char charData = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char)\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printHexCharLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charData|)\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE197_Numeric_Truncation_Error__int_rand_to_char_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") . (equal (v/value data) -655697577)))
    :free-variables '(("data" "int" :-CONST :-REGISTER))
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* POTENTIAL FLAW: Convert data to a char, possibly causing a truncation error *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 67) (:DECLARES "charData") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 68) (:DECLARES "charData") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char charData = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char)\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printHexCharLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charData|)\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE197_Numeric_Truncation_Error__int_rand_to_char_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE197_Numeric_Truncation_Error__int_rand_to_char_01_bad_top_level_inline
    :patches (list printHexCharLine_patch CWE197_Numeric_Truncation_Error__int_rand_to_char_01_bad_top_level_inline_patch)))

(defvar CWE252_Unchecked_Return_Value__char_fprintf_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE252_Unchecked_Return_Value__char_fprintf_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdio.h>")
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE252_Unchecked_Return_Value__char_fprintf_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE252_Unchecked_Return_Value__char_fprintf_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE252_Unchecked_Return_Value__char_fprintf_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \\/* FLAW: Do not check the return value *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 4) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fprintf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"stdout\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"%s\\\\n\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"string\\\"\"") "\"\"") "\")\"") "\";\\r\\n}\"") "\"\""))))

(defvar CWE252_Unchecked_Return_Value__char_fprintf_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables 'NIL
    :includes '("<stdio.h>")
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 4) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fprintf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"stdout\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"%s\\\\n\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"string\\\"\"") "\"\"") "\")\""))))


(define-scion CWE252_Unchecked_Return_Value__char_fprintf_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE252_Unchecked_Return_Value__char_fprintf_01_bad_top_level_inline
    :patches (list CWE252_Unchecked_Return_Value__char_fprintf_01_bad_top_level_inline_patch)))

(defvar CWE253_Incorrect_Check_of_Function_Return_Value__char_fprintf_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE253_Incorrect_Check_of_Function_Return_Value__char_fprintf_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdio.h>")
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE253_Incorrect_Check_of_Function_Return_Value__char_fprintf_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE253_Incorrect_Check_of_Function_Return_Value__char_fprintf_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE253_Incorrect_Check_of_Function_Return_Value__char_fprintf_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \\/* FLAW: fprintf() might fail, in which case the return value will be negative, but\\r\\n     * we are checking to see if the return value is 0 *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 4) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fprintf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"stdout\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"%s\\\\n\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"string\\\"\"") "\"\"") "\")\"") "\" == \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"fprintf failed!\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE253_Incorrect_Check_of_Function_Return_Value__char_fprintf_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables 'NIL
    :includes '("<stdio.h>")
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 4) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fprintf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"stdout\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"%s\\\\n\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"string\\\"\"") "\"\"") "\")\"") "\" == \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"fprintf failed!\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\""))))


(define-scion CWE253_Incorrect_Check_of_Function_Return_Value__char_fprintf_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE253_Incorrect_Check_of_Function_Return_Value__char_fprintf_01_bad_top_level_inline
    :patches (list printLine_patch CWE253_Incorrect_Check_of_Function_Return_Value__char_fprintf_01_bad_top_level_inline_patch)))

(defvar CWE367_TOC_TOU__access_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE367_TOC_TOU__access_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<fcntl.h>" "<stddef.h>" "<stdio.h>" "<stdlib.h>" "<string.h>" "<unistd.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100))
    :macros '(#S(CLANG-MACRO :HASH -7379358396012845812 :NAME "CLOSE" :BODY "CLOSE close") #S(CLANG-MACRO :HASH -2251689809414035892 :NAME "BAD_SINK_STRING" :BODY "BAD_SINK_STRING \"Bad Sink...\"") #S(CLANG-MACRO :HASH 7993643387143623974 :NAME "WRITE" :BODY "WRITE write") #S(CLANG-MACRO :HASH 1558538643793173296 :NAME "OPEN" :BODY "OPEN open") #S(CLANG-MACRO :HASH -3165941349971436421 :NAME "ACCESS" :BODY "ACCESS access") #S(CLANG-MACRO :HASH 4723192209568994710 :NAME "STAT" :BODY "STAT stat") #S(CLANG-MACRO :HASH 3525616155471961188 :NAME "GOOD_SINK_STRING" :BODY "GOOD_SINK_STRING \"Good Sink...\""))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE367_TOC_TOU__access_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<stddef.h>" "<stdio.h>" "<stdlib.h>" "<string.h>" "<unistd.h>") (:IS-DECL . T) (:MACROS 1558538643793173296 7993643387143623974 -7379358396012845812 -3165941349971436421 -2251689809414035892) (:NAME . "CWE367_TOC_TOU__access_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE367_TOC_TOU__access_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<stddef.h>" "<stdio.h>" "<stdlib.h>" "<string.h>" "<unistd.h>") (:IS-DECL) (:MACROS 1558538643793173296 7993643387143623974 -7379358396012845812 -3165941349971436421 -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<stddef.h>" "<stdio.h>" "<stdlib.h>" "<string.h>" "<unistd.h>") (:IS-DECL) (:MACROS 1558538643793173296 7993643387143623974 -7379358396012845812 -3165941349971436421 -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "filename") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "filename") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char filename[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"] = \"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"\\\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 8) (:DECLARES "fileDesc") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 9) (:DECLARES "fileDesc") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int fileDesc = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fgets|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"stdin\"") "\")\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"fgets() failed\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n            \\/* Restore NUL terminator if fgets fails *\\/\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . ">") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\")\"") "\" > \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\")\"") "\"-\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* remove newline *\\/\\r\\n        }\"") "\"\"") "\"\\r\\n        \\/* FLAW: Open and write to the file after checking the status information *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>" "<unistd.h>") (:IS-DECL) (:MACROS -3165941349971436421) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -3165941349971436421) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -3165941349971436421) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -3165941349971436421) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ACCESS\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"W_OK\"") "\")\"") "\" == \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"  = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 85) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"OPEN\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 87) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 88) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 89) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 90) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"O_RDWR\"") "\")\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 91) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 92) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 93) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 94) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 95) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 96) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 97) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 98) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 99) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 100) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 101) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 102) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>" "<string.h>" "<unistd.h>") (:IS-DECL) (:MACROS 7993643387143623974 -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 103) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>" "<unistd.h>") (:IS-DECL) (:MACROS 7993643387143623974 -2251689809414035892) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 104) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>" "<unistd.h>") (:IS-DECL) (:MACROS 7993643387143623974 -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 105) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS 7993643387143623974) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"WRITE\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 107) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 108) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 109) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"BAD_SINK_STRING\"") "\", \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 112) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 113) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 114) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 115) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"BAD_SINK_STRING\"") "\")\"") "\")\"") "\" == \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 118) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 119) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 120) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 121) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 122) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 123) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 124) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 125) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 126) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 127) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 128) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 129) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 130) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 131) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 132) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 133) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 134) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"CLOSE\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 136) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 137) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE367_TOC_TOU__access_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"")) "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"")) . (equal (v/value fileDesc) -1)))
    :free-variables '(("filename" "[100]char" :-CONST :-REGISTER) ("fileDesc" "int" :-CONST :-REGISTER))
    :includes '("<fcntl.h>" "<stddef.h>" "<stdio.h>" "<stdlib.h>" "<string.h>" "<unistd.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100))
    :macros '(#S(CLANG-MACRO :HASH -7379358396012845812 :NAME "CLOSE" :BODY "CLOSE close") #S(CLANG-MACRO :HASH -2251689809414035892 :NAME "BAD_SINK_STRING" :BODY "BAD_SINK_STRING \"Bad Sink...\"") #S(CLANG-MACRO :HASH 7993643387143623974 :NAME "WRITE" :BODY "WRITE write") #S(CLANG-MACRO :HASH 1558538643793173296 :NAME "OPEN" :BODY "OPEN open") #S(CLANG-MACRO :HASH -3165941349971436421 :NAME "ACCESS" :BODY "ACCESS access") #S(CLANG-MACRO :HASH 4723192209568994710 :NAME "STAT" :BODY "STAT stat") #S(CLANG-MACRO :HASH 3525616155471961188 :NAME "GOOD_SINK_STRING" :BODY "GOOD_SINK_STRING \"Good Sink...\""))
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<stddef.h>" "<stdio.h>" "<stdlib.h>" "<string.h>" "<unistd.h>") (:IS-DECL) (:MACROS 1558538643793173296 7993643387143623974 -7379358396012845812 -3165941349971436421 -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 6253389274476629705) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 6253389274476629705) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"")) "\" = \"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"\\\"\"")) "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"")) "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"")) "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fgets|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"stdin\"") "\")\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"fgets() failed\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n            \\/* Restore NUL terminator if fgets fails *\\/\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . ">") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\")\"") "\" > \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\")\"") "\"-\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* remove newline *\\/\\r\\n        }\"") "\"\"") "\"\\r\\n        \\/* FLAW: Open and write to the file after checking the status information *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>" "<unistd.h>") (:IS-DECL) (:MACROS -3165941349971436421) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -3165941349971436421) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -3165941349971436421) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -3165941349971436421) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ACCESS\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"W_OK\"") "\")\"") "\" == \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"  = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 85) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"OPEN\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 87) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 88) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 89) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 90) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"O_RDWR\"") "\")\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 91) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 92) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 93) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 94) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 95) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 96) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 97) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 98) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 99) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 100) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 101) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 102) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>" "<string.h>" "<unistd.h>") (:IS-DECL) (:MACROS 7993643387143623974 -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 103) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>" "<unistd.h>") (:IS-DECL) (:MACROS 7993643387143623974 -2251689809414035892) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 104) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>" "<unistd.h>") (:IS-DECL) (:MACROS 7993643387143623974 -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 105) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS 7993643387143623974) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"WRITE\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 107) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 108) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 109) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"BAD_SINK_STRING\"") "\", \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 112) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 113) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 114) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 115) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -2251689809414035892) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"BAD_SINK_STRING\"") "\")\"") "\")\"") "\" == \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 118) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 119) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 120) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 121) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 122) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 123) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 124) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 125) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 126) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 127) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 128) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 129) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 130) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 131) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 132) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 133) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 134) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"CLOSE\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 136) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 137) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\""))))


(define-scion CWE367_TOC_TOU__access_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE367_TOC_TOU__access_01_bad_top_level_inline
    :patches (list printLine_patch CWE367_TOC_TOU__access_01_bad_top_level_inline_patch)))

(defvar CWE369_Divide_by_Zero__int_rand_divide_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE369_Divide_by_Zero__int_rand_divide_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE369_Divide_by_Zero__int_rand_divide_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE369_Divide_by_Zero__int_rand_divide_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE369_Divide_by_Zero__int_rand_divide_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int data\"") "\"\"") "\";\\r\\n    \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Set data to a random value *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Possibly divide by zero *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "/") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\" \\/ \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n}\"") "\"\""))))

(defvar CWE369_Divide_by_Zero__int_rand_divide_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") . (equal (v/value data) -1390015979)))
    :free-variables '(("data" "int" :-CONST :-REGISTER))
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "/") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\" \\/ \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\""))))


(define-scion CWE369_Divide_by_Zero__int_rand_divide_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE369_Divide_by_Zero__int_rand_divide_01_bad_top_level_inline
    :patches (list printIntLine_patch CWE369_Divide_by_Zero__int_rand_divide_01_bad_top_level_inline_patch)))

(defvar CWE377_Insecure_Temporary_File__char_tempnam_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE377_Insecure_Temporary_File__char_tempnam_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<fcntl.h>" "<stddef.h>" "<stdio.h>" "<stdlib.h>" "<sys/stat.h>" "<unistd.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -7379358396012845812 :NAME "CLOSE" :BODY "CLOSE close") #S(CLANG-MACRO :HASH 1558538643793173296 :NAME "OPEN" :BODY "OPEN open") #S(CLANG-MACRO :HASH 7044633915514794449 :NAME "TEMPNAM" :BODY "TEMPNAM tempnam") #S(CLANG-MACRO :HASH -1506273811393726077 :NAME "MKSTEMP" :BODY "MKSTEMP mkstemp"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE377_Insecure_Temporary_File__char_tempnam_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<stddef.h>" "<stdio.h>" "<stdlib.h>" "<sys/stat.h>" "<unistd.h>") (:IS-DECL . T) (:MACROS 1558538643793173296 7044633915514794449 -7379358396012845812) (:NAME . "CWE377_Insecure_Temporary_File__char_tempnam_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE377_Insecure_Temporary_File__char_tempnam_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<stddef.h>" "<stdio.h>" "<stdlib.h>" "<sys/stat.h>" "<unistd.h>") (:IS-DECL) (:MACROS 1558538643793173296 7044633915514794449 -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<stddef.h>" "<stdio.h>" "<stdlib.h>" "<sys/stat.h>" "<unistd.h>") (:IS-DECL) (:MACROS 1558538643793173296 7044633915514794449 -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "filename") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "filename") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * filename\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 6) (:DECLARES "fileDesc") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 7) (:DECLARES "fileDesc") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int fileDesc\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS 7044633915514794449) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS 7044633915514794449) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS 7044633915514794449) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"TEMPNAM\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\")\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \\/* FLAW: Open a temporary file using open() and flags that do not prevent a race condition *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"OPEN\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"O_RDWR|O_CREAT\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<sys/stat.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"S_IREAD|S_IWRITE\"") "\")\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Temporary file was opened...now closing file\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"CLOSE\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE377_Insecure_Temporary_File__char_tempnam_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS 7044633915514794449) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS 7044633915514794449) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS 7044633915514794449) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"TEMPNAM\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\")\"") "\"\"") . (equal (v/size filename) 16)))
    :free-variables '(("filename" "*char" :-CONST :-REGISTER) ("fileDesc" "int" :-CONST :-REGISTER))
    :includes '("<fcntl.h>" "<stddef.h>" "<stdio.h>" "<stdlib.h>" "<sys/stat.h>" "<unistd.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -7379358396012845812 :NAME "CLOSE" :BODY "CLOSE close") #S(CLANG-MACRO :HASH 1558538643793173296 :NAME "OPEN" :BODY "OPEN open") #S(CLANG-MACRO :HASH 7044633915514794449 :NAME "TEMPNAM" :BODY "TEMPNAM tempnam") #S(CLANG-MACRO :HASH -1506273811393726077 :NAME "MKSTEMP" :BODY "MKSTEMP mkstemp"))
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<stddef.h>" "<stdio.h>" "<stdlib.h>" "<sys/stat.h>" "<unistd.h>") (:IS-DECL) (:MACROS 1558538643793173296 7044633915514794449 -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" "\"\\r\\n        \"" "\"\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS 7044633915514794449) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS 7044633915514794449) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS 7044633915514794449) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"TEMPNAM\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\")\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \\/* FLAW: Open a temporary file using open() and flags that do not prevent a race condition *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"OPEN\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"O_RDWR|O_CREAT\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<sys/stat.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"S_IREAD|S_IWRITE\"") "\")\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Temporary file was opened...now closing file\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -7379358396012845812) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"CLOSE\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE377_Insecure_Temporary_File__char_tempnam_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE377_Insecure_Temporary_File__char_tempnam_01_bad_top_level_inline
    :patches (list printLine_patch CWE377_Insecure_Temporary_File__char_tempnam_01_bad_top_level_inline_patch)))

(defvar CWE398_Poor_Code_Quality__addition_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE398_Poor_Code_Quality__addition_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes 'NIL
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE398_Poor_Code_Quality__addition_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME . "CWE398_Poor_Code_Quality__addition_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE398_Poor_Code_Quality__addition_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "intOne" "intTwo" "intSum") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "intOne") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "LISTELT") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int intOne = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 7) (:DECLARES "intTwo") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "LISTELT") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"intTwo = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 9) (:DECLARES "intSum") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FINALLISTELT") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"intSum = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intSum|)\"") "\"\"") "\")\"") "\";\\r\\n        \\/* FLAW: the statement has no effect *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intOne|)\"") "\"\"") "\" + \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intTwo|)\"") "\"\"") "\"\"") "\"; \\/* This generates a compiler warning, but we expect it to *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intSum|)\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE398_Poor_Code_Quality__addition_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intOne|)\"")) "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"")) . (equal (v/value intOne) 1)))
    :free-variables '(("intOne" "int" :-CONST :-REGISTER))
    :includes 'NIL
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intOne|)\"")) "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"")) "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intSum|)\"") "\"\"") "\")\"") "\";\\r\\n        \\/* FLAW: the statement has no effect *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intOne|)\"") "\"\"") "\" + \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intTwo|)\"") "\"\"") "\"\"") "\"; \\/* This generates a compiler warning, but we expect it to *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intSum|)\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE398_Poor_Code_Quality__addition_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE398_Poor_Code_Quality__addition_01_bad_top_level_inline
    :patches (list printIntLine_patch CWE398_Poor_Code_Quality__addition_01_bad_top_level_inline_patch)))

(defvar CWE400_Resource_Exhaustion__rand_for_loop_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE400_Resource_Exhaustion__rand_for_loop_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/home/jruchti/synth/bin/../lib/clang/6.0.1/include/stddef.h" :LINE 62 :HASH 764611252874068922 :I-FILE "<stddef.h>" :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "size_t" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE400_Resource_Exhaustion__rand_for_loop_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE400_Resource_Exhaustion__rand_for_loop_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE400_Resource_Exhaustion__rand_for_loop_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "count") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "count") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int count\"") "\"\"") "\";\\r\\n    \\/* Initialize count *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|count|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Set count to a random value *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|count|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 67) (:DECLARES "i") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 68) (:DECLARES "i") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"size_t i = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: For loop using count as the loop variant and no validation *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "FORSTMT") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"for (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\" < \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(size_t)\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|count|)\"") "\"\"") "\"\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "++") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"++\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 85) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 86) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 87) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 88) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 89) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 90) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Hello\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE400_Resource_Exhaustion__rand_for_loop_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|count|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|count|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") . (equal (v/value count) -260275780)))
    :free-variables '(("count" "int" :-CONST :-REGISTER))
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/home/jruchti/synth/bin/../lib/clang/6.0.1/include/stddef.h" :LINE 62 :HASH 764611252874068922 :I-FILE "<stddef.h>" :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "size_t" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|count|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|count|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 67) (:DECLARES "i") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 68) (:DECLARES "i") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"size_t i = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: For loop using count as the loop variant and no validation *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "FORSTMT") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"for (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\" < \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(size_t)\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|count|)\"") "\"\"") "\"\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "++") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"++\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 85) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 86) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 87) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 88) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 89) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 90) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Hello\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\""))))


(define-scion CWE400_Resource_Exhaustion__rand_for_loop_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE400_Resource_Exhaustion__rand_for_loop_01_bad_top_level_inline
    :patches (list printLine_patch CWE400_Resource_Exhaustion__rand_for_loop_01_bad_top_level_inline_patch)))

(defvar CWE401_Memory_Leak__int_malloc_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE401_Memory_Leak__int_malloc_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2241398076656181049 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE401_Memory_Leak__int_malloc_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE401_Memory_Leak__int_malloc_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE401_Memory_Leak__int_malloc_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Allocate memory on the heap *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(int *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(int)\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n    \\/* Initialize and make use of data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"5\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\"\"") "\")\"") "\";\\r\\n    \\/* POTENTIAL FLAW: No deallocation *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "NULLSTMT") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\";\"") "\" \\/* empty statement needed for some flow variants *\\/\\r\\n}\"") "\"\""))))

(defvar CWE401_Memory_Leak__int_malloc_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(int *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(int)\"") "\"\"") "\")\"") "\"\"") "\"\"") . (equal (v/size data) 400)))
    :free-variables '(("data" "*int" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2241398076656181049 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(int *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(int)\"") "\"\"") "\")\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"5\"") "\"\"") (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\"\"") "\")\"") (((:ARGS) (:CLASS . "NULLSTMT") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\";\""))))


(define-scion CWE401_Memory_Leak__int_malloc_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE401_Memory_Leak__int_malloc_01_bad_top_level_inline
    :patches (list printIntLine_patch CWE401_Memory_Leak__int_malloc_01_bad_top_level_inline_patch)))

(defvar CWE404_Improper_Resource_Shutdown__open_fclose_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE404_Improper_Resource_Shutdown__open_fclose_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<fcntl.h>" "<stdio.h>" "<sys/stat.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/usr/include/stdio.h" :LINE 48 :HASH 3647496794580001440 :I-FILE "<stdio.h>" :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "FILE" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 1558538643793173296 :NAME "OPEN" :BODY "OPEN open") #S(CLANG-MACRO :HASH -7379358396012845812 :NAME "CLOSE" :BODY "CLOSE close"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE404_Improper_Resource_Shutdown__open_fclose_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<stdio.h>" "<sys/stat.h>") (:IS-DECL . T) (:MACROS 1558538643793173296) (:NAME . "CWE404_Improper_Resource_Shutdown__open_fclose_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE404_Improper_Resource_Shutdown__open_fclose_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<stdio.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int data\"") "\"\"") "\";\\r\\n    \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Open a file - need to make sure it is closed properly in the sink *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"OPEN\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSource_open.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"O_RDWR|O_CREAT\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<sys/stat.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"S_IREAD|S_IWRITE\"") "\")\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* FLAW: Attempt to close the file using fclose() instead of close() *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fclose|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(FILE *)\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE404_Improper_Resource_Shutdown__open_fclose_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"OPEN\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSource_open.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"O_RDWR|O_CREAT\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<sys/stat.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"S_IREAD|S_IWRITE\"") "\")\"") "\"\"") . (equal (v/value data) 4)))
    :free-variables '(("data" "int" :-CONST :-REGISTER))
    :includes '("<fcntl.h>" "<stdio.h>" "<sys/stat.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/usr/include/stdio.h" :LINE 48 :HASH 3647496794580001440 :I-FILE "<stdio.h>" :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "FILE" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 1558538643793173296 :NAME "OPEN" :BODY "OPEN open") #S(CLANG-MACRO :HASH -7379358396012845812 :NAME "CLOSE" :BODY "CLOSE close"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"OPEN\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSource_open.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"O_RDWR|O_CREAT\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<sys/stat.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"S_IREAD|S_IWRITE\"") "\")\"") "\"\"") (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* FLAW: Attempt to close the file using fclose() instead of close() *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fclose|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(FILE *)\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\""))))


(define-scion CWE404_Improper_Resource_Shutdown__open_fclose_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE404_Improper_Resource_Shutdown__open_fclose_01_bad_top_level_inline
    :patches (list CWE404_Improper_Resource_Shutdown__open_fclose_01_bad_top_level_inline_patch)))

(defvar CWE415_Double_Free__malloc_free_int_31_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE415_Double_Free__malloc_free_int_31_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2241398076656181049 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE415_Double_Free__malloc_free_int_31_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE415_Double_Free__malloc_free_int_31_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE415_Double_Free__malloc_free_int_31_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int * data\"") "\"\"") "\";\\r\\n    \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(int *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(int)\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n    \\/* POTENTIAL FLAW: Free data in the source - the bad sink frees data as well *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 42) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 43) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int * dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 46) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 47) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: Possibly freeing memory twice *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE415_Double_Free__malloc_free_int_31_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(int *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(int)\"") "\"\"") "\")\"") "\"\"") "\"\"") . (equal (v/size data) 400)))
    :free-variables '(("data" "*int" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2241398076656181049 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(int *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(int)\"") "\"\"") "\")\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 42) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 43) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int * dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 46) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 47) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: Possibly freeing memory twice *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE415_Double_Free__malloc_free_int_31_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE415_Double_Free__malloc_free_int_31_bad_top_level_inline
    :patches (list CWE415_Double_Free__malloc_free_int_31_bad_top_level_inline_patch)))

(defvar CWE426_Untrusted_Search_Path__char_system_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE426_Untrusted_Search_Path__char_system_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -6429760151768931699 :NAME "SYSTEM" :BODY "SYSTEM system") #S(CLANG-MACRO :HASH 3371904807624756031 :NAME "BAD_OS_COMMAND" :BODY "BAD_OS_COMMAND \"ls -la\"") #S(CLANG-MACRO :HASH -3046674180685201017 :NAME "GOOD_OS_COMMAND" :BODY "GOOD_OS_COMMAND \"/usr/bin/ls -la\""))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE426_Untrusted_Search_Path__char_system_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>" "<string.h>") (:IS-DECL . T) (:MACROS 3371904807624756031 -6429760151768931699) (:NAME . "CWE426_Untrusted_Search_Path__char_system_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE426_Untrusted_Search_Path__char_system_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 3371904807624756031 -6429760151768931699) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 5) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 6) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char dataBuffer[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"] = \"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"\\\"\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\";\\r\\n    \\/* FLAW: the full path is not specified *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS 3371904807624756031) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 3371904807624756031) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"BAD_OS_COMMAND\"") "\")\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Executing the system() function without specifying the full path to the executable\\r\\n     * can allow an attacker to run their own program *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -6429760151768931699) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -6429760151768931699) (:NAME) (:OPCODE . "<=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -6429760151768931699) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -6429760151768931699) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"SYSTEM\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\" <= \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"command execution failed!\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE426_Untrusted_Search_Path__char_system_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables '(("data" "*char" :-CONST :-REGISTER) ("dataBuffer" "[100]char" :-CONST :-REGISTER))
    :includes '("<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -6429760151768931699 :NAME "SYSTEM" :BODY "SYSTEM system") #S(CLANG-MACRO :HASH 3371904807624756031 :NAME "BAD_OS_COMMAND" :BODY "BAD_OS_COMMAND \"ls -la\"") #S(CLANG-MACRO :HASH -3046674180685201017 :NAME "GOOD_OS_COMMAND" :BODY "GOOD_OS_COMMAND \"/usr/bin/ls -la\""))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 6253389274476629705) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 6253389274476629705) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"\\\"\"")) (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS 3371904807624756031) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 3371904807624756031) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"BAD_OS_COMMAND\"") "\")\"") (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -6429760151768931699) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -6429760151768931699) (:NAME) (:OPCODE . "<=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -6429760151768931699) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -6429760151768931699) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"SYSTEM\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\" <= \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"command execution failed!\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\")\"") "\";\\r\\n    }\"") "\"\""))))


(define-scion CWE426_Untrusted_Search_Path__char_system_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE426_Untrusted_Search_Path__char_system_01_bad_top_level_inline
    :patches (list printLine_patch CWE426_Untrusted_Search_Path__char_system_01_bad_top_level_inline_patch)))

(defvar CWE459_Incomplete_Cleanup__char_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE459_Incomplete_Cleanup__char_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdio.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/usr/include/stdio.h" :LINE 48 :HASH 3647496794580001440 :I-FILE "<stdio.h>" :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "FILE" :SIZE 8) #S(CLANG-TYPE :ARRAY "[]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 4286207319223806414 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE NIL))
    :macros '(#S(CLANG-MACRO :HASH -3470641226466452289 :NAME "FDOPEN" :BODY "FDOPEN fdopen") #S(CLANG-MACRO :HASH -1506273811393726077 :NAME "MKSTEMP" :BODY "MKSTEMP mkstemp") #S(CLANG-MACRO :HASH 4880025556042520325 :NAME "UNLINK" :BODY "UNLINK unlink"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE459_Incomplete_Cleanup__char_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>" "<stdlib.h>") (:IS-DECL . T) (:MACROS -3470641226466452289 -1506273811393726077) (:NAME . "CWE459_Incomplete_Cleanup__char_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE459_Incomplete_Cleanup__char_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>" "<stdlib.h>") (:IS-DECL) (:MACROS -3470641226466452289 -1506273811393726077) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>" "<stdlib.h>") (:IS-DECL) (:MACROS -3470641226466452289 -1506273811393726077) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "filename") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "filename") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 4286207319223806414) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char filename[] = \"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"badXXXXXX\\\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 7) (:DECLARES "pFile") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 8) (:DECLARES "pFile") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FILE *pFile\"") "\"\"") "\";\\r\\n        \\/* Establish that this is a temporary file and that it should be deleted *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 9) (:DECLARES "fileDesc") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -1506273811393726077) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 10) (:DECLARES "fileDesc") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS -1506273811393726077) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int fileDesc = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -1506273811393726077) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -1506273811393726077) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"MKSTEMP\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS -3470641226466452289) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS -3470641226466452289) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS -3470641226466452289) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pFile|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS -3470641226466452289) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS -3470641226466452289) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FDOPEN\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"w\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pFile|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n                \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fprintf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pFile|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Temporary file\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n                \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fclose|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pFile|)\"") "\"\"") "\")\"") "\";\\r\\n                \\/* FLAW: We don't unlink *\\/\\r\\n            }\"") "\"\"") "\"\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE459_Incomplete_Cleanup__char_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -1506273811393726077) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -1506273811393726077) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"MKSTEMP\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\")\"")) . (equal (v/value fileDesc) 4)))
    :free-variables '(("filename" "[]char" :-CONST :-REGISTER) ("pFile" "*FILE" :-CONST :-REGISTER) ("fileDesc" "int" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdio.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/usr/include/stdio.h" :LINE 48 :HASH 3647496794580001440 :I-FILE "<stdio.h>" :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "FILE" :SIZE 8) #S(CLANG-TYPE :ARRAY "[]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 4286207319223806414 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE NIL))
    :macros '(#S(CLANG-MACRO :HASH -3470641226466452289 :NAME "FDOPEN" :BODY "FDOPEN fdopen") #S(CLANG-MACRO :HASH -1506273811393726077 :NAME "MKSTEMP" :BODY "MKSTEMP mkstemp") #S(CLANG-MACRO :HASH 4880025556042520325 :NAME "UNLINK" :BODY "UNLINK unlink"))
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>" "<stdlib.h>") (:IS-DECL) (:MACROS -3470641226466452289 -1506273811393726077) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" "\"\\r\\n        \"" "\"\\r\\n        \\/* Establish that this is a temporary file and that it should be deleted *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -1506273811393726077) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -1506273811393726077) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"MKSTEMP\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|filename|)\"") "\"\"") "\")\"")) "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS -3470641226466452289) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS -3470641226466452289) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS -3470641226466452289) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pFile|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS -3470641226466452289) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS -3470641226466452289) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FDOPEN\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fileDesc|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"w\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pFile|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n                \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fprintf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pFile|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Temporary file\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n                \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fclose|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pFile|)\"") "\"\"") "\")\"") "\";\\r\\n                \\/* FLAW: We don't unlink *\\/\\r\\n            }\"") "\"\"") "\"\\r\\n        }\"") "\"\"") "\"\\r\\n    }\""))))


(define-scion CWE459_Incomplete_Cleanup__char_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE459_Incomplete_Cleanup__char_01_bad_top_level_inline
    :patches (list CWE459_Incomplete_Cleanup__char_01_bad_top_level_inline_patch)))

(defvar CWE464_Addition_of_Data_Structure_Sentinel__basic_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE464_Addition_of_Data_Structure_Sentinel__basic_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<libio.h>" "<stdio.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[4]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -5892687046710376854 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "[2]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -3317663057540178253 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 2))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE464_Addition_of_Data_Structure_Sentinel__basic_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<libio.h>" "<stdio.h>" "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE464_Addition_of_Data_Structure_Sentinel__basic_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE464_Addition_of_Data_Structure_Sentinel__basic_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<libio.h>" "<stdio.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"' '\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<libio.h>" "<stdio.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 10) (:DECLARES "charArraySource") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 11) (:DECLARES "charArraySource") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -3317663057540178253) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char charArraySource[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"]\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<libio.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySource|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<libio.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<libio.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"getc(stdin)\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySource|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n        \\/* FLAW: If the character entered on the command line is not an int,\\r\\n         * a null value will be returned *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|atoi|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySource|)\"") "\"\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n    }\"") "\"\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 41) (:DECLARES "charArraySink") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 42) (:DECLARES "charArraySink") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -5892687046710376854) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char charArraySink[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"4\"") "\"]\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySink|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'x'\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: If data is null, the rest of the array will not be printed *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySink|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySink|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'z'\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySink|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"3\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySink|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE464_Addition_of_Data_Structure_Sentinel__basic_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"' '\"") "\"\"") "\"\"") . (equal (v/value data) 32)))
    :free-variables '(("data" "char" :-CONST :-REGISTER))
    :includes '("<libio.h>" "<stdio.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[4]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -5892687046710376854 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "[2]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -3317663057540178253 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 2))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"' '\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<libio.h>" "<stdio.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 10) (:DECLARES "charArraySource") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 11) (:DECLARES "charArraySource") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -3317663057540178253) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char charArraySource[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"]\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<libio.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySource|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<libio.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<libio.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"getc(stdin)\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySource|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n        \\/* FLAW: If the character entered on the command line is not an int,\\r\\n         * a null value will be returned *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|atoi|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySource|)\"") "\"\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n    }\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 41) (:DECLARES "charArraySink") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 42) (:DECLARES "charArraySink") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -5892687046710376854) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char charArraySink[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"4\"") "\"]\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySink|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'x'\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: If data is null, the rest of the array will not be printed *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySink|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySink|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'z'\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySink|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"3\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charArraySink|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE464_Addition_of_Data_Structure_Sentinel__basic_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE464_Addition_of_Data_Structure_Sentinel__basic_01_bad_top_level_inline
    :patches (list printLine_patch CWE464_Addition_of_Data_Structure_Sentinel__basic_01_bad_top_level_inline_patch)))

(defvar CWE467_Use_of_sizeof_on_Pointer_Type__char_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE467_Use_of_sizeof_on_Pointer_Type__char_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE467_Use_of_sizeof_on_Pointer_Type__char_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE467_Use_of_sizeof_on_Pointer_Type__char_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE467_Use_of_sizeof_on_Pointer_Type__char_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "badChar") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "badChar") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * badChar = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\"\"") "\";\\r\\n        \\/* FLAW: Using sizeof the pointer and not the data type in malloc() *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof\"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\")\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\"\"") "\"\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'B'\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printHexCharLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE467_Use_of_sizeof_on_Pointer_Type__char_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"")) "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"")) . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof\"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\")\"") "\"\"") "\")\"") "\"\"") "\"\"") . (equal (v/size badChar) 8)))
    :free-variables '(("badChar" "*char" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"")) "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"")) "\";\\r\\n        \\/* FLAW: Using sizeof the pointer and not the data type in malloc() *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof\"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\")\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\"\"") "\"\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'B'\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printHexCharLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|badChar|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE467_Use_of_sizeof_on_Pointer_Type__char_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE467_Use_of_sizeof_on_Pointer_Type__char_01_bad_top_level_inline
    :patches (list printHexCharLine_patch CWE467_Use_of_sizeof_on_Pointer_Type__char_01_bad_top_level_inline_patch)))

(defvar CWE475_Undefined_Behavior_for_Input_to_API__char_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE475_Undefined_Behavior_for_Input_to_API__char_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE475_Undefined_Behavior_for_Input_to_API__char_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE475_Undefined_Behavior_for_Input_to_API__char_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE475_Undefined_Behavior_for_Input_to_API__char_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char dataBuffer[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"] = \"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"\\\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 8) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 9) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"abcdefghijklmnopqrstuvwxyz\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \\/* FLAW: Copy overlapping memory regions using memcpy() for which the result is undefined *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" + \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"6\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" + \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"4\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"10\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE475_Undefined_Behavior_for_Input_to_API__char_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables '(("dataBuffer" "[100]char" :-CONST :-REGISTER) ("data" "*char" :-CONST :-REGISTER))
    :includes '("<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 6253389274476629705) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 6253389274476629705) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"\\\"\"")) "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"")) "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"")) "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"abcdefghijklmnopqrstuvwxyz\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \\/* FLAW: Copy overlapping memory regions using memcpy() for which the result is undefined *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" + \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"6\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" + \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"4\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"10\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE475_Undefined_Behavior_for_Input_to_API__char_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE475_Undefined_Behavior_for_Input_to_API__char_01_bad_top_level_inline
    :patches (list printLine_patch CWE475_Undefined_Behavior_for_Input_to_API__char_01_bad_top_level_inline_patch)))

(defvar CWE476_NULL_Pointer_Dereference__int_31_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE476_NULL_Pointer_Dereference__int_31_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2241398076656181049 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE476_NULL_Pointer_Dereference__int_31_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE476_NULL_Pointer_Dereference__int_31_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE476_NULL_Pointer_Dereference__int_31_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int * data\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Set data to NULL *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 12) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 13) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int * dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 16) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 17) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: Attempt to use data, which may be NULL *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE476_NULL_Pointer_Dereference__int_31_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables '(("data" "*int" :-CONST :-REGISTER))
    :includes '("<stddef.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2241398076656181049 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 12) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 13) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int * dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 16) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 17) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: Attempt to use data, which may be NULL *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE476_NULL_Pointer_Dereference__int_31_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE476_NULL_Pointer_Dereference__int_31_bad_top_level_inline
    :patches (list printIntLine_patch CWE476_NULL_Pointer_Dereference__int_31_bad_top_level_inline_patch)))

(defvar CWE478_Missing_Default_Case_in_Switch__basic_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE478_Missing_Default_Case_in_Switch__basic_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1944158543856436560 :I-FILE NIL :POINTER T :CONST T :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE478_Missing_Default_Case_in_Switch__basic_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE478_Missing_Default_Case_in_Switch__basic_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE478_Missing_Default_Case_in_Switch__basic_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "charString") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "charString") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1944158543856436560) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"const char *charString = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"shouldn\\\\'t see this value\\\"\"") "\"\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 9) (:DECLARES "x") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 10) (:DECLARES "x") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int x\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"") "\" = \"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"3\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "SWITCHSTMT") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"switch (\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CASESTMT") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"case \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\":\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charString|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"0\\\"\"") "\"\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BREAKSTMT") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"break\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CASESTMT") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"case \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\":\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charString|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"1\\\"\"") "\"\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BREAKSTMT") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"break\"") "\";\\r\\n            \\/* FLAW: x could be 2, and there is no 'default' case for that *\\/\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charString|)\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE478_Missing_Default_Case_in_Switch__basic_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"") "\" = \"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"3\"") "\"\"") "\")\"") "\"\"") . (equal (v/value x) 1)))
    :free-variables '(("charString" "*char" :+CONST :-REGISTER) ("x" "int" :-CONST :-REGISTER))
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1944158543856436560 :I-FILE NIL :POINTER T :CONST T :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1944158543856436560) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1944158543856436560) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charString|)\"")) "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"shouldn\\\\'t see this value\\\"\"") "\"\"") "\"\"")) "\";\\r\\n        \"" "\"\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"") "\" = \"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"3\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "SWITCHSTMT") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"switch (\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CASESTMT") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"case \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\":\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charString|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"0\\\"\"") "\"\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BREAKSTMT") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"break\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CASESTMT") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"case \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\":\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charString|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"1\\\"\"") "\"\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BREAKSTMT") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"break\"") "\";\\r\\n            \\/* FLAW: x could be 2, and there is no 'default' case for that *\\/\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charString|)\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE478_Missing_Default_Case_in_Switch__basic_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE478_Missing_Default_Case_in_Switch__basic_01_bad_top_level_inline
    :patches (list printLine_patch CWE478_Missing_Default_Case_in_Switch__basic_01_bad_top_level_inline_patch)))

(defvar helperBad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "helperBad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS ("sig" -1958391046879680490)) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "helperBad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "helperBad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"static void helperBad(\"" (((:ARGS) (:CLASS . "PARMVAR") (:COUNTER . 2) (:DECLARES "sig") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int sig\"") "\")\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \\/* FLAW: malloc and free are not re-entrant *\\/\\r\\n    \\/* Used to be printf in here, but we are trying to avoid that.\\r\\n     * Detecting that printLine ultimately calls printf requires inter-\\r\\n     * procedural analysis, so we cannot do that either.  So instead,\\r\\n     * do something very contrived with malloc\\/free\\r\\n     *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "voidPointer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "voidPointer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void *voidPointer = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"10\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|voidPointer|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|voidPointer|)\"") "\"\"") "\")\"") "\";\\r\\n}\"") "\"\""))))


(defvar CWE479_Signal_Handler_Use_of_Non_Reentrant_Function__basic_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE479_Signal_Handler_Use_of_Non_Reentrant_Function__basic_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<signal.h>")
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 38) (:DECLARES "CWE479_Signal_Handler_Use_of_Non_Reentrant_Function__basic_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<signal.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE479_Signal_Handler_Use_of_Non_Reentrant_Function__basic_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE479_Signal_Handler_Use_of_Non_Reentrant_Function__basic_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<signal.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<signal.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<signal.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<signal.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|signal|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<signal.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"SIGINT\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|helperBad|)\"") "\"\"") "\")\"") "\";\\r\\n}\"") "\"\""))))

(defvar CWE479_Signal_Handler_Use_of_Non_Reentrant_Function__basic_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables 'NIL
    :includes '("<signal.h>")
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<signal.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<signal.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<signal.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|signal|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<signal.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"SIGINT\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|helperBad|)\"") "\"\"") "\")\""))))


(define-scion CWE479_Signal_Handler_Use_of_Non_Reentrant_Function__basic_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE479_Signal_Handler_Use_of_Non_Reentrant_Function__basic_01_bad_top_level_inline
    :patches (list helperBad_patch CWE479_Signal_Handler_Use_of_Non_Reentrant_Function__basic_01_bad_top_level_inline_patch)))

(defvar CWE481_Assigning_Instead_of_Comparing__basic_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE481_Assigning_Instead_of_Comparing__basic_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE481_Assigning_Instead_of_Comparing__basic_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE481_Assigning_Instead_of_Comparing__basic_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE481_Assigning_Instead_of_Comparing__basic_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "intRand") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "intRand") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int intRand = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\"\"") "\"\"") "\";\\r\\n        \\/* FLAW: should be == and INCIDENTIAL CWE 571 Expression Is Always True *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intRand|)\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"5\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"i was 5\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE481_Assigning_Instead_of_Comparing__basic_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intRand|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"")) . (equal (v/value intRand) 986867113)))
    :free-variables '(("intRand" "int" :-CONST :-REGISTER))
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intRand|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"")) "\";\\r\\n        \\/* FLAW: should be == and INCIDENTIAL CWE 571 Expression Is Always True *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intRand|)\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"5\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"i was 5\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\""))))


(define-scion CWE481_Assigning_Instead_of_Comparing__basic_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE481_Assigning_Instead_of_Comparing__basic_01_bad_top_level_inline
    :patches (list printLine_patch CWE481_Assigning_Instead_of_Comparing__basic_01_bad_top_level_inline_patch)))

(defvar CWE482_Comparing_Instead_of_Assigning__basic_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE482_Comparing_Instead_of_Assigning__basic_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes 'NIL
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE482_Comparing_Instead_of_Assigning__basic_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME . "CWE482_Comparing_Instead_of_Assigning__basic_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE482_Comparing_Instead_of_Assigning__basic_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "intBadSink") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "intBadSink") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int intBadSink = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\";\\r\\n        \\/* Print original value to avoid any unused variable incidentals *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intBadSink|)\"") "\"\"") "\")\"") "\";\\r\\n        \\/* FLAW: meant to assign 5 to intBadSink.  Maintenance note: may generate a compiler warning, this is intentional *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intBadSink|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"5\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intBadSink|)\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE482_Comparing_Instead_of_Assigning__basic_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intBadSink|)\"")) "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"")) . (equal (v/value intBadSink) 0)))
    :free-variables '(("intBadSink" "int" :-CONST :-REGISTER))
    :includes 'NIL
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intBadSink|)\"")) "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"")) "\";\\r\\n        \\/* Print original value to avoid any unused variable incidentals *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intBadSink|)\"") "\"\"") "\")\"") "\";\\r\\n        \\/* FLAW: meant to assign 5 to intBadSink.  Maintenance note: may generate a compiler warning, this is intentional *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intBadSink|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"5\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intBadSink|)\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE482_Comparing_Instead_of_Assigning__basic_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE482_Comparing_Instead_of_Assigning__basic_01_bad_top_level_inline
    :patches (list printIntLine_patch CWE482_Comparing_Instead_of_Assigning__basic_01_bad_top_level_inline_patch)))

(defvar CWE483_Incorrect_Block_Delimitation__semicolon_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE483_Incorrect_Block_Delimitation__semicolon_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE483_Incorrect_Block_Delimitation__semicolon_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE483_Incorrect_Block_Delimitation__semicolon_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE483_Incorrect_Block_Delimitation__semicolon_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "x") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "x") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int x = \"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"3\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 12) (:DECLARES "y") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 13) (:DECLARES "y") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int y = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\";\\r\\n        \\/* FLAW: Suspicious semicolon before the if statement brace *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\")\"" (((:ARGS) (:CLASS . "NULLSTMT") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "UNBRACEDBODY") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\";\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"x == 0\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|y|)\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\";\\r\\n        }\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|y|)\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"x was 0\\\\n\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE483_Incorrect_Block_Delimitation__semicolon_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"")) "\" = \"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"3\"") "\"\"") "\")\"")) . (equal (v/value x) 1))((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|y|)\"")) "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"")) . (equal (v/value y) 0)))
    :free-variables '(("x" "int" :-CONST :-REGISTER) ("y" "int" :-CONST :-REGISTER))
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"")) "\" = \"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"3\"") "\"\"") "\")\"")) "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|y|)\"")) "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"")) "\";\\r\\n        \\/* FLAW: Suspicious semicolon before the if statement brace *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\")\"" (((:ARGS) (:CLASS . "NULLSTMT") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "UNBRACEDBODY") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\";\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"x == 0\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|y|)\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\";\\r\\n        }\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|y|)\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"x was 0\\\\n\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\""))))


(define-scion CWE483_Incorrect_Block_Delimitation__semicolon_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE483_Incorrect_Block_Delimitation__semicolon_01_bad_top_level_inline
    :patches (list printLine_patch CWE483_Incorrect_Block_Delimitation__semicolon_01_bad_top_level_inline_patch)))

(defvar CWE484_Omitted_Break_Statement_in_Switch__basic_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE484_Omitted_Break_Statement_in_Switch__basic_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE484_Omitted_Break_Statement_in_Switch__basic_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE484_Omitted_Break_Statement_in_Switch__basic_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE484_Omitted_Break_Statement_in_Switch__basic_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "x") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "x") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int x = \"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"3\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \\/* FLAW: Missing break in first case *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "SWITCHSTMT") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"switch (\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CASESTMT") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"case \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\":\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"0\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CASESTMT") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"case \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\":\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"1\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BREAKSTMT") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"break\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CASESTMT") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"case \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\":\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"2\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BREAKSTMT") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"break\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DEFAULTSTMT") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"default:\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Invalid Number\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BREAKSTMT") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"break\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE484_Omitted_Break_Statement_in_Switch__basic_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"")) "\" = \"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"3\"") "\"\"") "\")\"")) . (equal (v/value x) 2)))
    :free-variables '(("x" "int" :-CONST :-REGISTER))
    :includes '("<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"")) "\" = \"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"3\"") "\"\"") "\")\"")) "\";\\r\\n        \\/* FLAW: Missing break in first case *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "SWITCHSTMT") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"switch (\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|x|)\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CASESTMT") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"case \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\":\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"0\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CASESTMT") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"case \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\":\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"1\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BREAKSTMT") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"break\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CASESTMT") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"case \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"2\"") "\":\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"2\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BREAKSTMT") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"break\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DEFAULTSTMT") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"default:\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Invalid Number\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BREAKSTMT") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"break\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\""))))


(define-scion CWE484_Omitted_Break_Statement_in_Switch__basic_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE484_Omitted_Break_Statement_in_Switch__basic_01_bad_top_level_inline
    :patches (list printLine_patch CWE484_Omitted_Break_Statement_in_Switch__basic_01_bad_top_level_inline_patch)))

(defvar CWE511_Logic_Time_Bomb__rand_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE511_Logic_Time_Bomb__rand_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>" "<time.h>" "<unistd.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 4880025556042520325 :NAME "UNLINK" :BODY "UNLINK unlink") #S(CLANG-MACRO :HASH -2866508520563029221 :NAME "NUM_CHECK" :BODY "NUM_CHECK 20000"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE511_Logic_Time_Bomb__rand_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<time.h>" "<unistd.h>") (:IS-DECL . T) (:MACROS 4880025556042520325 -2866508520563029221) (:NAME . "CWE511_Logic_Time_Bomb__rand_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE511_Logic_Time_Bomb__rand_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<time.h>" "<unistd.h>") (:IS-DECL) (:MACROS 4880025556042520325 -2866508520563029221) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<time.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 4) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|srand|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<time.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(unsigned)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<time.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<time.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<time.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|time|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\")\"") "\"\"") "\")\"") "\";\\r\\n    \\/* FLAW: If a certain number, delete a file *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>" "<unistd.h>") (:IS-DECL) (:MACROS 4880025556042520325 -2866508520563029221) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -2866508520563029221) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -2866508520563029221) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NUM_CHECK\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS 4880025556042520325) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS 4880025556042520325) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS 4880025556042520325) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"UNLINK\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"important_file.txt\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE511_Logic_Time_Bomb__rand_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>" "<time.h>" "<unistd.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 4880025556042520325 :NAME "UNLINK" :BODY "UNLINK unlink") #S(CLANG-MACRO :HASH -2866508520563029221 :NAME "NUM_CHECK" :BODY "NUM_CHECK 20000"))
    :code '((((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<time.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 4) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|srand|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<time.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(unsigned)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<time.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<time.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<time.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|time|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\")\"") "\"\"") "\")\"") (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>" "<unistd.h>") (:IS-DECL) (:MACROS 4880025556042520325 -2866508520563029221) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS -2866508520563029221) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -2866508520563029221) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NUM_CHECK\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS 4880025556042520325) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS 4880025556042520325) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS 4880025556042520325) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"UNLINK\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"important_file.txt\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\""))))


(define-scion CWE511_Logic_Time_Bomb__rand_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE511_Logic_Time_Bomb__rand_01_bad_top_level_inline
    :patches (list CWE511_Logic_Time_Bomb__rand_01_bad_top_level_inline_patch)))

(defvar CWE526_Info_Exposure_Environment_Variables__basic_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE526_Info_Exposure_Environment_Variables__basic_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdlib.h>")
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE526_Info_Exposure_Environment_Variables__basic_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE526_Info_Exposure_Environment_Variables__basic_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE526_Info_Exposure_Environment_Variables__basic_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \\/* FLAW: environment variable exposed *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 4) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|getenv|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"PATH\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\")\"") "\";\\r\\n}\"") "\"\""))))

(defvar CWE526_Info_Exposure_Environment_Variables__basic_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables 'NIL
    :includes '("<stdlib.h>")
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 4) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|getenv|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"PATH\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\")\""))))


(define-scion CWE526_Info_Exposure_Environment_Variables__basic_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE526_Info_Exposure_Environment_Variables__basic_01_bad_top_level_inline
    :patches (list printLine_patch CWE526_Info_Exposure_Environment_Variables__basic_01_bad_top_level_inline_patch)))

(defvar staticReturnsTrue_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "staticReturnsTrue" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes 'NIL
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "staticReturnsTrue") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME . "staticReturnsTrue") (:OPCODE) (:RET . -1958391046879680490) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"static int staticReturnsTrue()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "RETURNSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"return \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 4) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\";\\r\\n}\"") "\"\""))))


(defvar CWE546_Suspicious_Comment__BUG_08_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE546_Suspicious_Comment__BUG_08_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes 'NIL
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 9) (:DECLARES "CWE546_Suspicious_Comment__BUG_08_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME . "CWE546_Suspicious_Comment__BUG_08_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE546_Suspicious_Comment__BUG_08_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if(\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|staticReturnsTrue|)\"") "\"\"") "\"()\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* FLAW: The following comment has the letters 'BUG' in it*\\/\\r\\n        \\/* BUG: This comment has the letters 'BUG' in it, which is certainly\\r\\n         * suspicious, because it could indicate this code has a BUG in it.\\r\\n         *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Hello\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE546_Suspicious_Comment__BUG_08_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables 'NIL
    :includes 'NIL
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if(\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|staticReturnsTrue|)\"") "\"\"") "\"()\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* FLAW: The following comment has the letters 'BUG' in it*\\/\\r\\n        \\/* BUG: This comment has the letters 'BUG' in it, which is certainly\\r\\n         * suspicious, because it could indicate this code has a BUG in it.\\r\\n         *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Hello\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\""))))


(define-scion CWE546_Suspicious_Comment__BUG_08_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE546_Suspicious_Comment__BUG_08_bad_top_level_inline
    :patches (list printLine_patch staticReturnsTrue_patch CWE546_Suspicious_Comment__BUG_08_bad_top_level_inline_patch)))

(defvar CWE570_Expression_Always_False__n_less_int_min_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE570_Expression_Always_False__n_less_int_min_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<limits.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE570_Expression_Always_False__n_less_int_min_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>" "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE570_Expression_Always_False__n_less_int_min_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE570_Expression_Always_False__n_less_int_min_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \\/* INCIDENTAL: CWE 338 - Use of Cryptographically Weak PRNG *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "intRand") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "intRand") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int intRand = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\"\"") "\"\"") "\";\\r\\n\\r\\n    \\/* FLAW: This expression is always false *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intRand|)\"") "\"\"") "\" < \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"INT_MIN\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Never prints\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE570_Expression_Always_False__n_less_int_min_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intRand|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"")) . (equal (v/value intRand) 599153291)))
    :free-variables '(("intRand" "int" :-CONST :-REGISTER))
    :includes '("<limits.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intRand|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"")) (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intRand|)\"") "\"\"") "\" < \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"INT_MIN\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Never prints\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\""))))


(define-scion CWE570_Expression_Always_False__n_less_int_min_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE570_Expression_Always_False__n_less_int_min_01_bad_top_level_inline
    :patches (list printLine_patch CWE570_Expression_Always_False__n_less_int_min_01_bad_top_level_inline_patch)))

(defvar CWE571_Expression_Always_True__n_less_int_max_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE571_Expression_Always_True__n_less_int_max_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<limits.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE571_Expression_Always_True__n_less_int_max_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>" "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE571_Expression_Always_True__n_less_int_max_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE571_Expression_Always_True__n_less_int_max_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \\/* INCIDENTAL: CWE 338 - Use of Cryptographically Weak PRNG *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "intRand") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "intRand") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int intRand = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\"\"") "\"\"") "\";\\r\\n\\r\\n    \\/* FLAW: This expression is always true *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intRand|)\"") "\"\"") "\" <= \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"INT_MAX\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Always prints\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE571_Expression_Always_True__n_less_int_max_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intRand|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"")) . (equal (v/value intRand) 1835408377)))
    :free-variables '(("intRand" "int" :-CONST :-REGISTER))
    :includes '("<limits.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intRand|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"")) (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intRand|)\"") "\"\"") "\" <= \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<limits.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"INT_MAX\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Always prints\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\""))))


(define-scion CWE571_Expression_Always_True__n_less_int_max_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE571_Expression_Always_True__n_less_int_max_01_bad_top_level_inline
    :patches (list printLine_patch CWE571_Expression_Always_True__n_less_int_max_01_bad_top_level_inline_patch)))

(defvar CWE587_Assignment_of_Fixed_Address_to_Pointer__basic_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE587_Assignment_of_Fixed_Address_to_Pointer__basic_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes 'NIL
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE587_Assignment_of_Fixed_Address_to_Pointer__basic_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME . "CWE587_Assignment_of_Fixed_Address_to_Pointer__basic_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE587_Assignment_of_Fixed_Address_to_Pointer__basic_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* FLAW: Assigning fixed address to pointer *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "charPointer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "charPointer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char *charPointer = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char*)\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0x400000\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printHexCharLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charPointer|)\"") "\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE587_Assignment_of_Fixed_Address_to_Pointer__basic_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables '(("charPointer" "*char" :-CONST :-REGISTER))
    :includes 'NIL
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* FLAW: Assigning fixed address to pointer *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charPointer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char*)\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0x400000\"") "\"\"")) "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printHexCharLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charPointer|)\"") "\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE587_Assignment_of_Fixed_Address_to_Pointer__basic_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE587_Assignment_of_Fixed_Address_to_Pointer__basic_01_bad_top_level_inline
    :patches (list printHexCharLine_patch CWE587_Assignment_of_Fixed_Address_to_Pointer__basic_01_bad_top_level_inline_patch)))

(defvar CWE590_Free_Memory_Not_on_Heap__free_char_alloca_31_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE590_Free_Memory_Not_on_Heap__free_char_alloca_31_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<alloca.h>" "<stddef.h>" "<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -342517378131665086 :NAME "ALLOCA" :BODY "ALLOCA alloca"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE590_Free_Memory_Not_on_Heap__free_char_alloca_31_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>" "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE590_Free_Memory_Not_on_Heap__free_char_alloca_31_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE590_Free_Memory_Not_on_Heap__free_char_alloca_31_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>" "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\"; \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* FLAW: data is allocated on the stack and deallocated in the BadSink *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 12) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 13) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727 -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataBuffer = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(100*sizeof(char))\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'A'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\"; \\/* fill with 'A's *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\";\\r\\n    }\"") "\"\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 47) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 48) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 51) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 52) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \\/* POTENTIAL FLAW: Possibly deallocating memory allocated on the stack *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE590_Free_Memory_Not_on_Heap__free_char_alloca_31_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables '(("data" "*char" :-CONST :-REGISTER))
    :includes '("<alloca.h>" "<stddef.h>" "<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -342517378131665086 :NAME "ALLOCA" :BODY "ALLOCA alloca"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* FLAW: data is allocated on the stack and deallocated in the BadSink *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 12) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 13) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727 -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataBuffer = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(100*sizeof(char))\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'A'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\"; \\/* fill with 'A's *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\";\\r\\n    }\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 47) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 48) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 51) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 52) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 60) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        \\/* POTENTIAL FLAW: Possibly deallocating memory allocated on the stack *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE590_Free_Memory_Not_on_Heap__free_char_alloca_31_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE590_Free_Memory_Not_on_Heap__free_char_alloca_31_bad_top_level_inline
    :patches (list printLine_patch CWE590_Free_Memory_Not_on_Heap__free_char_alloca_31_bad_top_level_inline_patch)))

(defvar CWE617_Reachable_Assertion__rand_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE617_Reachable_Assertion__rand_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<assert.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 2826451665740210303 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE NIL) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))") #S(CLANG-MACRO :HASH 560588087248213234 :NAME "ASSERT_VALUE" :BODY "ASSERT_VALUE 5"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE617_Reachable_Assertion__rand_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<assert.h>" "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE617_Reachable_Assertion__rand_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE617_Reachable_Assertion__rand_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<assert.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int data\"") "\"\"") "\";\\r\\n    \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Set data to a random value *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: this assertion could trigger if n <= ASSERT_VALUE *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<assert.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 2826451665740210303) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"assert((|data|) > ASSERT_VALUE)\"") "\";\\r\\n}\"") "\"\""))))

(defvar CWE617_Reachable_Assertion__rand_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") . T))
    :free-variables '(("data" "int" :-CONST :-REGISTER))
    :includes '("<assert.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 2826451665740210303 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE NIL) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))") #S(CLANG-MACRO :HASH 560588087248213234 :NAME "ASSERT_VALUE" :BODY "ASSERT_VALUE 5"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<assert.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 2826451665740210303) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"assert((|data|) > ASSERT_VALUE)\""))))


(define-scion CWE617_Reachable_Assertion__rand_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE617_Reachable_Assertion__rand_01_bad_top_level_inline
    :patches (list CWE617_Reachable_Assertion__rand_01_bad_top_level_inline_patch)))

(defvar CWE665_Improper_Initialization__char_cat_31_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE665_Improper_Initialization__char_cat_31_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE665_Improper_Initialization__char_cat_31_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE665_Improper_Initialization__char_cat_31_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE665_Improper_Initialization__char_cat_31_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 5) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 6) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char dataBuffer[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"]\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\";\\r\\n    \\/* FLAW: Do not initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "NULLSTMT") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\";\"") "\" \\/* empty statement needed for some flow variants *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 14) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 15) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 18) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 19) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 23) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 24) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char source[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"]\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'C'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\"; \\/* fill with 'C's *\\/\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n            \\/* POTENTIAL FLAW: If data is not initialized properly, strcat() may not function correctly *\\/\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcat|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE665_Improper_Initialization__char_cat_31_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables '(("data" "*char" :-CONST :-REGISTER) ("dataBuffer" "[100]char" :-CONST :-REGISTER))
    :includes '("<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "NULLSTMT") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\";\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 14) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 15) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 18) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 19) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 23) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 24) (:DECLARES "source") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char source[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"]\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|memset|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'C'\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\"; \\/* fill with 'C's *\\/\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\"; \\/* null terminate *\\/\\r\\n            \\/* POTENTIAL FLAW: If data is not initialized properly, strcat() may not function correctly *\\/\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcat|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|source|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\\r\\n    }\""))))


(define-scion CWE665_Improper_Initialization__char_cat_31_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE665_Improper_Initialization__char_cat_31_bad_top_level_inline
    :patches (list printLine_patch CWE665_Improper_Initialization__char_cat_31_bad_top_level_inline_patch)))

(defvar helperBad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "helperBad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes 'NIL
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "helperBad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME . "helperBad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"static void helperBad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \\/* FLAW: this function causes infinite recursion *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 4) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|helperBad|)\"") "\"\"") "\"()\"") "\"; \\/* maintenance note: this may generate a warning, this is on purpose *\\/\\r\\n}\"") "\"\""))))


(defvar CWE674_Uncontrolled_Recursion__infinite_recursive_call_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE674_Uncontrolled_Recursion__infinite_recursive_call_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes 'NIL
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 6) (:DECLARES "CWE674_Uncontrolled_Recursion__infinite_recursive_call_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME . "CWE674_Uncontrolled_Recursion__infinite_recursive_call_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE674_Uncontrolled_Recursion__infinite_recursive_call_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|helperBad|)\"") "\"\"") "\"()\"") "\";\\r\\n}\"") "\"\""))))

(defvar helperBad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables 'NIL
    :includes 'NIL
    :types 'NIL
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 4) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|helperBad|)\"") "\"\"") "\"()\""))))


(define-scion CWE674_Uncontrolled_Recursion__infinite_recursive_call_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE674_Uncontrolled_Recursion__infinite_recursive_call_01_bad_top_level_inline
    :patches (list helperBad_top_level_inline_patch)))

(defvar CWE675_Duplicate_Operations_on_Resource__fopen_31_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE675_Duplicate_Operations_on_Resource__fopen_31_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdio.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/usr/include/stdio.h" :LINE 48 :HASH 3647496794580001440 :I-FILE "<stdio.h>" :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "FILE" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE675_Duplicate_Operations_on_Resource__fopen_31_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE675_Duplicate_Operations_on_Resource__fopen_31_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE675_Duplicate_Operations_on_Resource__fopen_31_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FILE * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\"; \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fopen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSource_fopen.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"w+\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Close the file in the source *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fclose|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\")\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 28) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 29) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FILE * dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 32) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 33) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FILE * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: Close the file in the sink (it may have been closed in the Source) *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fclose|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE675_Duplicate_Operations_on_Resource__fopen_31_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fopen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSource_fopen.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"w+\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") . (equal (v/size data) 552)))
    :free-variables '(("data" "*FILE" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdio.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/usr/include/stdio.h" :LINE 48 :HASH 3647496794580001440 :I-FILE "<stdio.h>" :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "FILE" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fopen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSource_fopen.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"w+\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fclose|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\")\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 28) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 29) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FILE * dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 32) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 33) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FILE * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: Close the file in the sink (it may have been closed in the Source) *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fclose|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE675_Duplicate_Operations_on_Resource__fopen_31_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE675_Duplicate_Operations_on_Resource__fopen_31_bad_top_level_inline
    :patches (list CWE675_Duplicate_Operations_on_Resource__fopen_31_bad_top_level_inline_patch)))

(defvar CWE680_Integer_Overflow_to_Buffer_Overflow__malloc_rand_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE680_Integer_Overflow_to_Buffer_Overflow__malloc_rand_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/home/jruchti/synth/bin/../lib/clang/6.0.1/include/stddef.h" :LINE 62 :HASH 764611252874068922 :I-FILE "<stddef.h>" :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "size_t" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2241398076656181049 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE680_Integer_Overflow_to_Buffer_Overflow__malloc_rand_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE680_Integer_Overflow_to_Buffer_Overflow__malloc_rand_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE680_Integer_Overflow_to_Buffer_Overflow__malloc_rand_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int data\"") "\"\"") "\";\\r\\n    \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Set data to a random value *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 67) (:DECLARES "i") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 68) (:DECLARES "i") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"size_t i\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 69) (:DECLARES "intPointer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 70) (:DECLARES "intPointer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int *intPointer\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: if data * sizeof(int) > SIZE_MAX, overflows to a small value\\r\\n         * so that the for loop doing the initialization causes a buffer overflow *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intPointer|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(int*)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\" * \"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(int)\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 85) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intPointer|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 86) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 90) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 91) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 92) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 93) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 94) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 95) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "FORSTMT") (:COUNTER . 96) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"for (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 97) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 98) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 99) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 100) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 101) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 102) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 103) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\" < \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 104) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(size_t)\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 105) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 106) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 107) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "++") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 108) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"++\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 109) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 110) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 111) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 112) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 113) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intPointer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 114) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 115) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 116) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"; \\/* Potentially writes beyond the boundary of intPointer *\\/\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 117) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 118) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 119) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 120) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 121) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 122) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 123) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intPointer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 124) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 125) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 126) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 127) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 128) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 129) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 130) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intPointer|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE680_Integer_Overflow_to_Buffer_Overflow__malloc_rand_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") . (equal (v/value data) 1065493497)))
    :free-variables '(("data" "int" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdlib.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/home/jruchti/synth/bin/../lib/clang/6.0.1/include/stddef.h" :LINE 62 :HASH 764611252874068922 :I-FILE "<stddef.h>" :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "size_t" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2241398076656181049 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -760642589583846522 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "unsigned int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 2308996158549424241 :NAME "URAND31" :BODY "URAND31() (((unsigned)rand()<<30) ^ ((unsigned)rand()<<15) ^ rand())") #S(CLANG-MACRO :HASH 1124813122759813294 :NAME "RAND32" :BODY "RAND32() ((int)(rand() & 1 ? URAND31() : -URAND31() - 1))"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490 -760642589583846522) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"RAND32()\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 67) (:DECLARES "i") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 68) (:DECLARES "i") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"size_t i\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 69) (:DECLARES "intPointer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 70) (:DECLARES "intPointer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int *intPointer\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: if data * sizeof(int) > SIZE_MAX, overflows to a small value\\r\\n         * so that the for loop doing the initialization causes a buffer overflow *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intPointer|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(int*)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\" * \"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(int)\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 85) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intPointer|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 86) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 90) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 91) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 92) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 93) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 94) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 95) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "FORSTMT") (:COUNTER . 96) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"for (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 97) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 98) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 99) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 100) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 101) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "<") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 102) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 103) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\" < \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 104) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(size_t)\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 105) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 106) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 107) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "++") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 108) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"++\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 109) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 110) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 111) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 112) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 113) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intPointer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 114) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 115) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 116) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"; \\/* Potentially writes beyond the boundary of intPointer *\\/\\r\\n        }\"") "\"\"") "\"\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 117) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 118) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 119) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 120) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 121) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 122) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 123) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intPointer|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 124) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 125) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 126) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 127) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 128) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 129) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 130) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intPointer|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE680_Integer_Overflow_to_Buffer_Overflow__malloc_rand_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE680_Integer_Overflow_to_Buffer_Overflow__malloc_rand_01_bad_top_level_inline
    :patches (list printIntLine_patch CWE680_Integer_Overflow_to_Buffer_Overflow__malloc_rand_01_bad_top_level_inline_patch)))

(defvar CWE685_Function_Call_With_Incorrect_Number_of_Arguments__basic_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE685_Function_Call_With_Incorrect_Number_of_Arguments__basic_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdio.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100))
    :macros '(#S(CLANG-MACRO :HASH -6999316518217383118 :NAME "SOURCE_STRING" :BODY "SOURCE_STRING \"AAA\"") #S(CLANG-MACRO :HASH 1185787598850764903 :NAME "DEST_SIZE" :BODY "DEST_SIZE 100 "))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE685_Function_Call_With_Incorrect_Number_of_Arguments__basic_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL . T) (:MACROS 1185787598850764903 -6999316518217383118) (:NAME . "CWE685_Function_Call_With_Incorrect_Number_of_Arguments__basic_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE685_Function_Call_With_Incorrect_Number_of_Arguments__basic_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS 1185787598850764903 -6999316518217383118) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS 1185787598850764903 -6999316518217383118) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "dest") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS 1185787598850764903) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "dest") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS 1185787598850764903) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char dest[\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 1185787598850764903) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"DEST_SIZE\"") "\"]\"") "\"\"") "\";\\r\\n        \\/* FLAW: Incorrect number of arguments *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS -6999316518217383118) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|sprintf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"%s %s\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -6999316518217383118) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"SOURCE_STRING\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE685_Function_Call_With_Incorrect_Number_of_Arguments__basic_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables '(("dest" "[100]char" :-CONST :-REGISTER))
    :includes '("<stdio.h>")
    :types '(#S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100))
    :macros '(#S(CLANG-MACRO :HASH -6999316518217383118 :NAME "SOURCE_STRING" :BODY "SOURCE_STRING \"AAA\"") #S(CLANG-MACRO :HASH 1185787598850764903 :NAME "DEST_SIZE" :BODY "DEST_SIZE 100 "))
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS 1185787598850764903 -6999316518217383118) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" "\"\\r\\n        \\/* FLAW: Incorrect number of arguments *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS -6999316518217383118) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|sprintf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"%s %s\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -6999316518217383118) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"SOURCE_STRING\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE685_Function_Call_With_Incorrect_Number_of_Arguments__basic_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE685_Function_Call_With_Incorrect_Number_of_Arguments__basic_01_bad_top_level_inline
    :patches (list printLine_patch CWE685_Function_Call_With_Incorrect_Number_of_Arguments__basic_01_bad_top_level_inline_patch)))

(defvar CWE688_Function_Call_With_Incorrect_Variable_or_Reference_as_Argument__basic_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE688_Function_Call_With_Incorrect_Variable_or_Reference_as_Argument__basic_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stdio.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100))
    :macros '(#S(CLANG-MACRO :HASH -1390543107768948573 :NAME "DEST_SIZE" :BODY "DEST_SIZE 100"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE688_Function_Call_With_Incorrect_Variable_or_Reference_as_Argument__basic_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL . T) (:MACROS -1390543107768948573) (:NAME . "CWE688_Function_Call_With_Incorrect_Variable_or_Reference_as_Argument__basic_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE688_Function_Call_With_Incorrect_Variable_or_Reference_as_Argument__basic_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS -1390543107768948573) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS -1390543107768948573) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "dest") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -1390543107768948573) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "dest") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS -1390543107768948573) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char dest[\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -1390543107768948573) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"DEST_SIZE\"") "\"]\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 7) (:DECLARES "intFive") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 8) (:DECLARES "intFive") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int intFive = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"5\"") "\"\"") "\"\"") "\";\\r\\n        \\/* FLAW: int argument passed, expecting string argument *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|sprintf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"%s\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intFive|)\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE688_Function_Call_With_Incorrect_Variable_or_Reference_as_Argument__basic_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intFive|)\"")) "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"5\"")) . (equal (v/value intFive) 5)))
    :free-variables '(("dest" "[100]char" :-CONST :-REGISTER) ("intFive" "int" :-CONST :-REGISTER))
    :includes '("<stdio.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4) #S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100))
    :macros '(#S(CLANG-MACRO :HASH -1390543107768948573 :NAME "DEST_SIZE" :BODY "DEST_SIZE 100"))
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS -1390543107768948573) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" "\"\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intFive|)\"")) "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"5\"")) "\";\\r\\n        \\/* FLAW: int argument passed, expecting string argument *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|sprintf|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"%s\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|intFive|)\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dest|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE688_Function_Call_With_Incorrect_Variable_or_Reference_as_Argument__basic_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE688_Function_Call_With_Incorrect_Variable_or_Reference_as_Argument__basic_01_bad_top_level_inline
    :patches (list printLine_patch CWE688_Function_Call_With_Incorrect_Variable_or_Reference_as_Argument__basic_01_bad_top_level_inline_patch)))

(defvar CWE690_NULL_Deref_From_Return__char_malloc_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE690_NULL_Deref_From_Return__char_malloc_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE690_NULL_Deref_From_Return__char_malloc_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE690_NULL_Deref_From_Return__char_malloc_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE690_NULL_Deref_From_Return__char_malloc_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\"; \\/* Initialize data *\\/\\r\\n    \\/* POTENTIAL FLAW: Allocate memory without checking if the memory allocation function failed *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"20\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n    \\/* FLAW: Initialize memory buffer without checking to see if the memory allocation function failed *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Initialize\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n}\"") "\"\""))))

(defvar CWE690_NULL_Deref_From_Return__char_malloc_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"20\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\"\"") "\"\"") . (equal (v/size data) 20)))
    :free-variables '(("data" "*char" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"20\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Initialize\\\"\"") "\"\"") "\"\"") "\")\"") (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\""))))


(define-scion CWE690_NULL_Deref_From_Return__char_malloc_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE690_NULL_Deref_From_Return__char_malloc_01_bad_top_level_inline
    :patches (list printLine_patch CWE690_NULL_Deref_From_Return__char_malloc_01_bad_top_level_inline_patch)))

(defvar CWE758_Undefined_Behavior__char_alloca_use_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE758_Undefined_Behavior__char_alloca_use_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<alloca.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -342517378131665086 :NAME "ALLOCA" :BODY "ALLOCA alloca"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE758_Undefined_Behavior__char_alloca_use_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE758_Undefined_Behavior__char_alloca_use_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE758_Undefined_Behavior__char_alloca_use_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 4) (:DECLARES "pointer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 5) (:DECLARES "pointer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727 -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * pointer = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(sizeof(char))\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 11) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 12) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pointer|)\"") "\"\"") "\"\"") "\"\"") "\"\"") "\"\"") "\"; \\/* FLAW: the value pointed to by pointer is undefined *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printHexCharLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE758_Undefined_Behavior__char_alloca_use_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pointer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(sizeof(char))\"") "\"\"")) . (equal (v/size pointer) 1))((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -2054504279541534951) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -2054504279541534951) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"")) "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pointer|)\"") "\"\"") "\"\"") "\"\"")) . (equal (v/value data) -96)))
    :free-variables '(("pointer" "*char" :-CONST :-REGISTER) ("data" "char" :-CONST :-REGISTER))
    :includes '("<alloca.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH -342517378131665086 :NAME "ALLOCA" :BODY "ALLOCA alloca"))
    :code '((((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 3) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 5790451697626571727) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pointer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<alloca.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ALLOCA(sizeof(char))\"") "\"\"")) "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -2054504279541534951) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -2054504279541534951) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"")) "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|pointer|)\"") "\"\"") "\"\"") "\"\"")) "\"; \\/* FLAW: the value pointed to by pointer is undefined *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printHexCharLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\")\"") "\";\\r\\n    }\""))))


(define-scion CWE758_Undefined_Behavior__char_alloca_use_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE758_Undefined_Behavior__char_alloca_use_01_bad_top_level_inline
    :patches (list printHexCharLine_patch CWE758_Undefined_Behavior__char_alloca_use_01_bad_top_level_inline_patch)))

(defvar CWE761_Free_Pointer_Not_at_Start_of_Buffer__char_environment_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE761_Free_Pointer_Not_at_Start_of_Buffer__char_environment_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/home/jruchti/synth/bin/../lib/clang/6.0.1/include/stddef.h" :LINE 62 :HASH 764611252874068922 :I-FILE "<stddef.h>" :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "size_t" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1))
    :macros '(#S(CLANG-MACRO :HASH -8515871080290371086 :NAME "SEARCH_CHAR" :BODY "SEARCH_CHAR 'S'") #S(CLANG-MACRO :HASH -4912265186542351092 :NAME "ENV_VARIABLE" :BODY "ENV_VARIABLE \"ADD\"") #S(CLANG-MACRO :HASH 2645724798783031398 :NAME "GETENV" :BODY "GETENV getenv"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE761_Free_Pointer_Not_at_Start_of_Buffer__char_environment_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL . T) (:MACROS 2645724798783031398 -8515871080290371086 -4912265186542351092) (:NAME . "CWE761_Free_Pointer_Not_at_Start_of_Buffer__char_environment_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE761_Free_Pointer_Not_at_Start_of_Buffer__char_environment_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 2645724798783031398 -8515871080290371086 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") "\"\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* Append input from an environment variable to data *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 37) (:DECLARES "dataLen") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 38) (:DECLARES "dataLen") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"size_t dataLen = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 45) (:DECLARES "environment") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 46) (:DECLARES "environment") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * environment = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS 2645724798783031398) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"GETENV\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ENV_VARIABLE\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \\/* If there is data in the environment variable *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|environment|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \\/* POTENTIAL FLAW: Read data from an environment variable *\\/\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strncat|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"+\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataLen|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|environment|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataLen|)\"") "\"\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") "\"\\r\\n    \\/* FLAW: We are incrementing the pointer in the loop - this will cause us to free the\\r\\n     * memory block not at the start of the buffer *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "FORSTMT") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -8515871080290371086) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"for (; \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 85) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 86) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 87) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 88) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 89) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "++") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 90) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"++\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 91) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -8515871080290371086) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 92) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -8515871080290371086) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 93) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -8515871080290371086) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 94) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 95) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 96) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 97) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 98) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 99) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -8515871080290371086) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"SEARCH_CHAR\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 100) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 101) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 102) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 103) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 104) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 105) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 106) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"We have a match!\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BREAKSTMT") (:COUNTER . 107) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"break\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") "\"\"") "\"\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 108) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 109) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 110) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 111) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 112) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 113) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n}\"") "\"\""))))

(defvar CWE761_Free_Pointer_Not_at_Start_of_Buffer__char_environment_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\"\"") "\"\"") . (equal (v/size data) 100)))
    :free-variables '(("data" "*char" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/home/jruchti/synth/bin/../lib/clang/6.0.1/include/stddef.h" :LINE 62 :HASH 764611252874068922 :I-FILE "<stddef.h>" :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "size_t" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1))
    :macros '(#S(CLANG-MACRO :HASH -8515871080290371086 :NAME "SEARCH_CHAR" :BODY "SEARCH_CHAR 'S'") #S(CLANG-MACRO :HASH -4912265186542351092 :NAME "ENV_VARIABLE" :BODY "ENV_VARIABLE \"ADD\"") #S(CLANG-MACRO :HASH 2645724798783031398 :NAME "GETENV" :BODY "GETENV getenv"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n    }\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "ARRAYSUBSCRIPTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"]\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* Append input from an environment variable to data *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 37) (:DECLARES "dataLen") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 38) (:DECLARES "dataLen") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"size_t dataLen = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 45) (:DECLARES "environment") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 46) (:DECLARES "environment") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * environment = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS 2645724798783031398) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"GETENV\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ENV_VARIABLE\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \\/* If there is data in the environment variable *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|environment|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \\/* POTENTIAL FLAW: Read data from an environment variable *\\/\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strncat|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"+\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataLen|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|environment|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataLen|)\"") "\"\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 80) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") (((:ARGS) (:CLASS . "FORSTMT") (:COUNTER . 81) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -8515871080290371086) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"for (; \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 82) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 83) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 84) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 85) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 86) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 87) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 88) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'\\\\0'\"") "\"\"") "\"; \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 89) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "++") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 90) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"++\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 91) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -8515871080290371086) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 92) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -8515871080290371086) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 93) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS -8515871080290371086) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 94) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 95) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 96) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 97) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 98) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 99) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -8515871080290371086) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"SEARCH_CHAR\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 100) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 101) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 102) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 103) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 104) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 105) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 106) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"We have a match!\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "BREAKSTMT") (:COUNTER . 107) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"break\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") "\"\"") (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 108) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 109) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 110) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 111) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 112) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 113) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\""))))


(define-scion CWE761_Free_Pointer_Not_at_Start_of_Buffer__char_environment_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE761_Free_Pointer_Not_at_Start_of_Buffer__char_environment_01_bad_top_level_inline
    :patches (list printLine_patch CWE761_Free_Pointer_Not_at_Start_of_Buffer__char_environment_01_bad_top_level_inline_patch)))

(defvar CWE773_Missing_Reference_to_Active_File_Descriptor_or_Handle__fopen_31_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE773_Missing_Reference_to_Active_File_Descriptor_or_Handle__fopen_31_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdio.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/usr/include/stdio.h" :LINE 48 :HASH 3647496794580001440 :I-FILE "<stdio.h>" :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "FILE" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE773_Missing_Reference_to_Active_File_Descriptor_or_Handle__fopen_31_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE773_Missing_Reference_to_Active_File_Descriptor_or_Handle__fopen_31_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE773_Missing_Reference_to_Active_File_Descriptor_or_Handle__fopen_31_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FILE * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Create a file handle using fopen() that may not be closed properly *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fopen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSource_fopen.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"w+\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 23) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 24) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FILE * dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 27) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 28) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FILE * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \\/* FLAW: Point data to another file handle without closing the handle from the source *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fopen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSink_fopen.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"w+\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n        \\/* avoid incidental for not closing the file handle *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fclose|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE773_Missing_Reference_to_Active_File_Descriptor_or_Handle__fopen_31_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fopen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSource_fopen.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"w+\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") . (equal (v/size data) 552)))
    :free-variables '(("data" "*FILE" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdio.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/usr/include/stdio.h" :LINE 48 :HASH 3647496794580001440 :I-FILE "<stdio.h>" :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "FILE" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fopen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSource_fopen.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"w+\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 23) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 24) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FILE * dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 27) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 28) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3647496794580001440) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"FILE * data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \\/* FLAW: Point data to another file handle without closing the handle from the source *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fopen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSink_fopen.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"w+\\\"\"") "\"\"") "\"\"") "\")\"") "\"\"") "\";\\r\\n        \\/* avoid incidental for not closing the file handle *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdio.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|fclose|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\""))))


(define-scion CWE773_Missing_Reference_to_Active_File_Descriptor_or_Handle__fopen_31_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE773_Missing_Reference_to_Active_File_Descriptor_or_Handle__fopen_31_bad_top_level_inline
    :patches (list CWE773_Missing_Reference_to_Active_File_Descriptor_or_Handle__fopen_31_bad_top_level_inline_patch)))

(defvar CWE775_Missing_Release_of_File_Descriptor_or_Handle__open_no_close_31_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE775_Missing_Release_of_File_Descriptor_or_Handle__open_no_close_31_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<fcntl.h>" "<sys/stat.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 1558538643793173296 :NAME "OPEN" :BODY "OPEN open") #S(CLANG-MACRO :HASH -7379358396012845812 :NAME "CLOSE" :BODY "CLOSE close"))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE775_Missing_Release_of_File_Descriptor_or_Handle__open_no_close_31_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL . T) (:MACROS 1558538643793173296) (:NAME . "CWE775_Missing_Release_of_File_Descriptor_or_Handle__open_no_close_31_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE775_Missing_Release_of_File_Descriptor_or_Handle__open_no_close_31_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int data\"") "\"\"") "\";\\r\\n    \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Open a file without closing it *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"OPEN\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSource_open.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"O_RDWR|O_CREAT\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<sys/stat.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"S_IREAD|S_IWRITE\"") "\")\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 24) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 25) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 28) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 29) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \\/* FLAW: No attempt to close the file *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "NULLSTMT") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\";\"") "\" \\/* empty statement needed for some flow variants *\\/\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE775_Missing_Release_of_File_Descriptor_or_Handle__open_no_close_31_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"OPEN\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSource_open.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"O_RDWR|O_CREAT\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<sys/stat.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"S_IREAD|S_IWRITE\"") "\")\"") "\"\"") . (equal (v/value data) 4)))
    :free-variables '(("data" "int" :-CONST :-REGISTER))
    :includes '("<fcntl.h>" "<sys/stat.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros '(#S(CLANG-MACRO :HASH 1558538643793173296 :NAME "OPEN" :BODY "OPEN open") #S(CLANG-MACRO :HASH -7379358396012845812 :NAME "CLOSE" :BODY "CLOSE close"))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<fcntl.h>" "<sys/stat.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS 1558538643793173296) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"OPEN\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"BadSource_open.txt\\\"\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<fcntl.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"O_RDWR|O_CREAT\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<sys/stat.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "|") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"S_IREAD|S_IWRITE\"") "\")\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 24) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 25) (:DECLARES "dataCopy") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int dataCopy = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 28) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 29) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int data = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataCopy|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \\/* FLAW: No attempt to close the file *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "NULLSTMT") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\";\"") "\" \\/* empty statement needed for some flow variants *\\/\\r\\n    }\""))))


(define-scion CWE775_Missing_Release_of_File_Descriptor_or_Handle__open_no_close_31_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE775_Missing_Release_of_File_Descriptor_or_Handle__open_no_close_31_bad_top_level_inline
    :patches (list CWE775_Missing_Release_of_File_Descriptor_or_Handle__open_no_close_31_bad_top_level_inline_patch)))

(defvar CWE789_Uncontrolled_Mem_Alloc__malloc_char_rand_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE789_Uncontrolled_Mem_Alloc__malloc_char_rand_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/home/jruchti/synth/bin/../lib/clang/6.0.1/include/stddef.h" :LINE 62 :HASH 764611252874068922 :I-FILE "<stddef.h>" :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "size_t" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH 1808983277519718612 :NAME "HELLO_STRING" :BODY "HELLO_STRING \"hello\""))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE789_Uncontrolled_Mem_Alloc__malloc_char_rand_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL . T) (:MACROS 1808983277519718612) (:NAME . "CWE789_Uncontrolled_Mem_Alloc__malloc_char_rand_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE789_Uncontrolled_Mem_Alloc__malloc_char_rand_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"size_t data\"") "\"\"") "\";\\r\\n    \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\";\\r\\n    \\/* POTENTIAL FLAW: Set data to a random value *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 16) (:DECLARES "myString") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 17) (:DECLARES "myString") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * myString\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: No MAXIMUM limitation for memory allocation, but ensure data is large enough\\r\\n         * for the strcpy() function to not cause a buffer overflow *\\/\\r\\n        \\/* INCIDENTAL FLAW: The source could cause a type overrun in data or in the memory allocation *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE . ">") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" > \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"HELLO_STRING\"") "\")\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|myString|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|myString|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n                \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n            }\"") "\"\"") "\"\\r\\n            \\/* Copy a small string into myString *\\/\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|myString|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"HELLO_STRING\"") "\")\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|myString|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|myString|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\" else \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Input is less than the length of the source string\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") "\"\\r\\n}\"") "\"\""))))

(defvar CWE789_Uncontrolled_Mem_Alloc__malloc_char_rand_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") . T)((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\"\"") "\"\"") . (equal (v/value data) 1923006201)))
    :free-variables '(("data" "size_t" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdlib.h>" "<string.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/home/jruchti/synth/bin/../lib/clang/6.0.1/include/stddef.h" :LINE 62 :HASH 764611252874068922 :I-FILE "<stddef.h>" :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "size_t" :SIZE 8))
    :macros '(#S(CLANG-MACRO :HASH 1808983277519718612 :NAME "HELLO_STRING" :BODY "HELLO_STRING \"hello\""))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|rand|)\"") "\"\"") "\"()\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 16) (:DECLARES "myString") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 17) (:DECLARES "myString") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * myString\"") "\"\"") "\";\\r\\n        \\/* POTENTIAL FLAW: No MAXIMUM limitation for memory allocation, but ensure data is large enough\\r\\n         * for the strcpy() function to not cause a buffer overflow *\\/\\r\\n        \\/* INCIDENTAL FLAW: The source could cause a type overrun in data or in the memory allocation *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE . ">") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\" > \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"HELLO_STRING\"") "\")\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 29) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|myString|)\"") "\" = \"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(char *)\"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|malloc|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 35) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 36) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 37) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"*\"" (((:ARGS) (:CLASS . "UNARYEXPRORTYPETRAITEXPR") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"sizeof(char)\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "==") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|myString|)\"") "\"\"") "\" == \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n                \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|exit|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"-\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\";\\r\\n            }\"") "\"\"") "\"\\r\\n            \\/* Copy a small string into myString *\\/\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strcpy|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|myString|)\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 1808983277519718612) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"HELLO_STRING\"") "\")\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 62) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 63) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 65) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 66) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|myString|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 68) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|free|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 70) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 72) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|myString|)\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\" else \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 73) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 74) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 75) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 76) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 77) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 78) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "STRINGLITERAL") (:COUNTER . 79) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\\\"Input is less than the length of the source string\\\"\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\""))))


(define-scion CWE789_Uncontrolled_Mem_Alloc__malloc_char_rand_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE789_Uncontrolled_Mem_Alloc__malloc_char_rand_01_bad_top_level_inline
    :patches (list printLine_patch CWE789_Uncontrolled_Mem_Alloc__malloc_char_rand_01_bad_top_level_inline_patch)))

(defvar CWE78_OS_Command_Injection__char_environment_execl_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE78_OS_Command_Injection__char_environment_execl_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>" "<stdlib.h>" "<string.h>" "<unistd.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/home/jruchti/synth/bin/../lib/clang/6.0.1/include/stddef.h" :LINE 62 :HASH 764611252874068922 :I-FILE "<stddef.h>" :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "size_t" :SIZE 8) #S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100))
    :macros '(#S(CLANG-MACRO :HASH 9084927035900116674 :NAME "COMMAND_ARG3" :BODY "COMMAND_ARG3 data") #S(CLANG-MACRO :HASH 4633345150827363949 :NAME "COMMAND_ARG1" :BODY "COMMAND_ARG1 \"-c\"") #S(CLANG-MACRO :HASH -2565974004529164926 :NAME "COMMAND_INT_PATH" :BODY "COMMAND_INT_PATH \"/bin/sh\"") #S(CLANG-MACRO :HASH -2425351531048995248 :NAME "EXECL" :BODY "EXECL execl") #S(CLANG-MACRO :HASH -4912265186542351092 :NAME "ENV_VARIABLE" :BODY "ENV_VARIABLE \"ADD\"") #S(CLANG-MACRO :HASH 2645724798783031398 :NAME "GETENV" :BODY "GETENV getenv") #S(CLANG-MACRO :HASH 1512811662678344236 :NAME "COMMAND_ARG2" :BODY "COMMAND_ARG2 \"ls \"") #S(CLANG-MACRO :HASH -2047303224589684749 :NAME "COMMAND_INT" :BODY "COMMAND_INT \"sh\""))
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE78_OS_Command_Injection__char_environment_execl_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>" "<unistd.h>") (:IS-DECL . T) (:MACROS 1512811662678344236 2645724798783031398 4633345150827363949 9084927035900116674 -4912265186542351092 -2565974004529164926 -2425351531048995248) (:NAME . "CWE78_OS_Command_Injection__char_environment_execl_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE78_OS_Command_Injection__char_environment_execl_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>" "<unistd.h>") (:IS-DECL) (:MACROS 1512811662678344236 2645724798783031398 4633345150827363949 9084927035900116674 -4912265186542351092 -2565974004529164926 -2425351531048995248) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * data\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 5) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS 1512811662678344236) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 6) (:DECLARES "dataBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS 1512811662678344236) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 6253389274476629705) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char dataBuffer[\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"] = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 1512811662678344236) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"COMMAND_ARG2\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* Append input from an environment variable to data *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 14) (:DECLARES "dataLen") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 15) (:DECLARES "dataLen") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"size_t dataLen = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 22) (:DECLARES "environment") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 23) (:DECLARES "environment") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * environment = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS 2645724798783031398) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"GETENV\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ENV_VARIABLE\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \\/* If there is data in the environment variable *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|environment|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \\/* POTENTIAL FLAW: Read data from an environment variable *\\/\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strncat|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"+\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataLen|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|environment|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataLen|)\"") "\"\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") "\"\\r\\n    \\/* execl - specify the path where the command is located *\\/\\r\\n    \\/* POTENTIAL FLAW: Execute command without validating input possibly leading to command injection *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<unistd.h>") (:IS-DECL) (:MACROS 4633345150827363949 9084927035900116674 -2565974004529164926 -2425351531048995248) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -2425351531048995248) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"EXECL\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -2565974004529164926) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"COMMAND_INT_PATH\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -2565974004529164926) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"COMMAND_INT_PATH\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 4633345150827363949) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"COMMAND_ARG1\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 9084927035900116674) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"COMMAND_ARG3\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\")\"") "\";\\r\\n}\"") "\"\""))))

(defvar CWE78_OS_Command_Injection__char_environment_execl_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 6253389274476629705) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 6253389274476629705) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 1512811662678344236) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"COMMAND_ARG2\"")) . (equal (v/value dataBuffer) 140736529796448)))
    :free-variables '(("data" "*char" :-CONST :-REGISTER) ("dataBuffer" "[100]char" :-CONST :-REGISTER))
    :includes '("<stddef.h>" "<stdlib.h>" "<string.h>" "<unistd.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 5790451697626571727 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 1 :DECL NIL :FILE "/home/jruchti/synth/bin/../lib/clang/6.0.1/include/stddef.h" :LINE 62 :HASH 764611252874068922 :I-FILE "<stddef.h>" :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "size_t" :SIZE 8) #S(CLANG-TYPE :ARRAY "[100]" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 6253389274476629705 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 100))
    :macros '(#S(CLANG-MACRO :HASH 9084927035900116674 :NAME "COMMAND_ARG3" :BODY "COMMAND_ARG3 data") #S(CLANG-MACRO :HASH 4633345150827363949 :NAME "COMMAND_ARG1" :BODY "COMMAND_ARG1 \"-c\"") #S(CLANG-MACRO :HASH -2565974004529164926 :NAME "COMMAND_INT_PATH" :BODY "COMMAND_INT_PATH \"/bin/sh\"") #S(CLANG-MACRO :HASH -2425351531048995248 :NAME "EXECL" :BODY "EXECL execl") #S(CLANG-MACRO :HASH -4912265186542351092 :NAME "ENV_VARIABLE" :BODY "ENV_VARIABLE \"ADD\"") #S(CLANG-MACRO :HASH 2645724798783031398 :NAME "GETENV" :BODY "GETENV getenv") #S(CLANG-MACRO :HASH 1512811662678344236 :NAME "COMMAND_ARG2" :BODY "COMMAND_ARG2 \"ls \"") #S(CLANG-MACRO :HASH -2047303224589684749 :NAME "COMMAND_INT" :BODY "COMMAND_INT \"sh\""))
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 6253389274476629705) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . 6253389274476629705) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"")) "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 1512811662678344236) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"COMMAND_ARG2\"")) (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataBuffer|)\"") "\"\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<stdlib.h>" "<string.h>") (:IS-DECL) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* Append input from an environment variable to data *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 14) (:DECLARES "dataLen") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 15) (:DECLARES "dataLen") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 764611252874068922) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"size_t dataLen = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strlen|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 22) (:DECLARES "environment") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 23) (:DECLARES "environment") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL . T) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 5790451697626571727) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char * environment = \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS 2645724798783031398 -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stdlib.h>") (:IS-DECL) (:MACROS 2645724798783031398) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"GETENV\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -4912265186542351092) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"ENV_VARIABLE\"") "\")\"") "\"\"") "\"\"") "\";\\r\\n        \\/* If there is data in the environment variable *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "IFSTMT") (:COUNTER . 30) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"if (\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 31) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "!=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 32) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 33) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|environment|)\"") "\"\"") "\" != \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 34) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\") \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 38) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n            \\/* POTENTIAL FLAW: Read data from an environment variable *\\/\\r\\n            \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 39) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 40) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 41) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<string.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|strncat|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 42) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 43) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 44) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"+\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 45) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 46) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataLen|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 47) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 48) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 49) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|environment|)\"") "\"\"") "\"\"") "\", \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 50) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 51) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "-") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 52) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 53) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"100\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 54) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 55) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|dataLen|)\"") "\"\"") "\"\"") "\"-\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 56) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 57) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n        }\"") "\"\"") "\"\\r\\n    }\"") (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 58) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>" "<unistd.h>") (:IS-DECL) (:MACROS 4633345150827363949 9084927035900116674 -2565974004529164926 -2425351531048995248) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 59) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<unistd.h>") (:IS-DECL) (:MACROS -2425351531048995248) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"EXECL\"") "\"(\"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 61) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -2565974004529164926) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"COMMAND_INT_PATH\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 64) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS -2565974004529164926) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"COMMAND_INT_PATH\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 67) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 4633345150827363949) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"COMMAND_ARG1\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 69) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES) (:IS-DECL) (:MACROS 9084927035900116674) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"COMMAND_ARG3\"") "\", \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 71) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\")\""))))


(define-scion CWE78_OS_Command_Injection__char_environment_execl_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE78_OS_Command_Injection__char_environment_execl_01_bad_top_level_inline
    :patches (list CWE78_OS_Command_Injection__char_environment_execl_01_bad_top_level_inline_patch)))

(defvar CWE835_Infinite_Loop__do_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE835_Infinite_Loop__do_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes 'NIL
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE835_Infinite_Loop__do_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME . "CWE835_Infinite_Loop__do_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE835_Infinite_Loop__do_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "i") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "i") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -1958391046879680490) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"int i = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\"\"") "\";\\r\\n\\r\\n    \\/* FLAW: Infinite Loop - do..while() with no break point *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "DOSTMT") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"do \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\" = \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\" + \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"256\"") "\"\"") "\"\"") "\";\\r\\n    }\"") "\" while(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . ">=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\" >= \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\")\"") "\";\\r\\n}\"") "\"\""))))

(defvar CWE835_Infinite_Loop__do_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '(((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"")) "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"")) . (equal (v/value i) 0)))
    :free-variables '(("i" "int" :-CONST :-REGISTER))
    :includes 'NIL
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -1958391046879680490 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 4))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER) (:DECLARES) (:EXPR-TYPE . -1958391046879680490) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"")) "\" = \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"")) (((:ARGS) (:CLASS . "DOSTMT") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"do \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 8) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 9) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 11) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 12) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\")\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\" = \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "%") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "+") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\" + \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"1\"") "\"\"") "\")\"") "\" % \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"256\"") "\"\"") "\"\"") "\";\\r\\n    }\"") "\" while(\"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT . T) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . ">=") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|i|)\"") "\"\"") "\" >= \"" (((:ARGS) (:CLASS . "INTEGERLITERAL") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"0\"") "\"\"") "\")\""))))


(define-scion CWE835_Infinite_Loop__do_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE835_Infinite_Loop__do_01_bad_top_level_inline
    :patches (list printIntLine_patch CWE835_Infinite_Loop__do_01_bad_top_level_inline_patch)))

(defvar CWE843_Type_Confusion__char_01_bad_patch
  (make-instance 'clang-static-patch
    :precondition (lambda (obj location)
  (and (= location 0)
       (not (member "CWE843_Type_Confusion__char_01_bad" (asts obj)
                    :test #'string=
                    :key [#'first #'ast-declares]))))
    :free-variables 'NIL
    :includes '("<stddef.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2241398076656181049 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "FUNCTION") (:COUNTER . 1) (:DECLARES "CWE843_Type_Confusion__char_01_bad") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL . T) (:MACROS) (:NAME . "CWE843_Type_Confusion__char_01_bad") (:OPCODE) (:RET . 2826451665740210303) (:SYN-CTX . "TOPLEVEL") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET . T) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void CWE843_Type_Confusion__char_01_bad()\\r\\n\"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 2) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n    \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 3) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 4) (:DECLARES "data") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"void * data\"") "\"\"") "\";\\r\\n    \\/* Initialize data *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") "\";\\r\\n    \"" (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* FLAW: Point data to a char *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 11) (:DECLARES "charBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 12) (:DECLARES "charBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char charBuffer = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'a'\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "&") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"&\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charBuffer|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n    }\"") "\"\\r\\n    \\/* POTENTIAL FLAW: Attempt to access data as an int *\\/\\r\\n    \"" (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(int*)\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\"\"") "\"\"") "\")\"") "\";\\r\\n}\"") "\"\""))))

(defvar CWE843_Type_Confusion__char_01_bad_top_level_inline_patch
  (make-instance 'clang-dynamic-patch
    :precondition NIL
    :conditional-code '()
    :free-variables '(("data" "*void" :-CONST :-REGISTER))
    :includes '("<stddef.h>")
    :types '(#S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2241398076656181049 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "int" :SIZE 8) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH -2054504279541534951 :I-FILE NIL :POINTER NIL :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "char" :SIZE 1) #S(CLANG-TYPE :ARRAY "" :COL 0 :DECL "" :FILE "" :LINE 0 :HASH 3615142211888308905 :I-FILE NIL :POINTER T :CONST NIL :VOLATILE NIL :RESTRICT NIL :STORAGE-CLASS :NONE :REQS NIL :NAME "void" :SIZE 8))
    :macros 'NIL
    :code '((((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 5) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 6) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "MACROEXPANSION") (:COUNTER . 7) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION . T) (:INCLUDES "<stddef.h>") (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES 3615142211888308905) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"NULL\"") "\"\"") (((:ARGS) (:CLASS . "COMPOUNDSTMT") (:COUNTER . 10) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "BRACED") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"{\\r\\n        \\/* FLAW: Point data to a char *\\/\\r\\n        \"" (((:ARGS) (:CLASS . "DECLSTMT") (:COUNTER . 11) (:DECLARES "charBuffer") (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "VAR") (:COUNTER . 12) (:DECLARES "charBuffer") (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL . T) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2054504279541534951) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"char charBuffer = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 13) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "CHARACTERLITERAL") (:COUNTER . 14) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"'a'\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n        \"" (((:ARGS) (:CLASS . "BINARYOPERATOR") (:COUNTER . 15) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "=") (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 16) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\" = \"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 17) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 18) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "&") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"&\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 19) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|charBuffer|)\"") "\"\"") "\"\"") "\"\"") "\";\\r\\n    }\"") (((:ARGS) (:CLASS . "CALLEXPR") (:COUNTER . 20) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT . T) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "FULLSTMT") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 21) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 22) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|printIntLine|)\"") "\"\"") "\"(\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 23) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "UNARYOPERATOR") (:COUNTER . 24) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE . "*") (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"*\"" (((:ARGS) (:CLASS . "PARENEXPR") (:COUNTER . 25) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(\"" (((:ARGS) (:CLASS . "CSTYLECASTEXPR") (:COUNTER . 26) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES -2241398076656181049) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(int*)\"" (((:ARGS) (:CLASS . "IMPLICITCASTEXPR") (:COUNTER . 27) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"\"" (((:ARGS) (:CLASS . "DECLREFEXPR") (:COUNTER . 28) (:DECLARES) (:EXPR-TYPE) (:FULL-STMT) (:GUARD-STMT) (:IN-MACRO-EXPANSION) (:INCLUDES) (:IS-DECL) (:MACROS) (:NAME) (:OPCODE) (:RET) (:SYN-CTX . "GENERIC") (:TYPES) (:UNBOUND-FUNS) (:UNBOUND-VALS) (:VARARGS) (:VOID-RET) (:ARRAY-LENGTH) (:BASE-TYPE) (:BIT-FIELD-WIDTH) (:AUX-DATA)) "\"(|data|)\"") "\"\"") "\"\"") "\")\"") "\"\"") "\"\"") "\")\""))))


(define-scion CWE843_Type_Confusion__char_01_bad_top_level_inline
  (make-instance 'clang-scion
    :name 'CWE843_Type_Confusion__char_01_bad_top_level_inline
    :patches (list printIntLine_patch CWE843_Type_Confusion__char_01_bad_top_level_inline_patch)))
